@@ -37,11 +37,11 @@ public:
     FXint execCmd(FXString);
     CommandWindow(FXWindow *owner, const FXString& name,  FXString strcmd, FXint nblines, FXint nbcols);
     CommandWindow(FXApp *a, const FXString& name,  FXString strcmd, FXint nblines, FXint nbcols);
-	long CommandWindow::onCmdClose(FXObject*,FXSelector,void*);
-	void CommandWindow::setText(const FXchar*);
-	void CommandWindow::appendText(const FXchar* str);
-	void CommandWindow::scrollToLastLine(void);
-	FXint CommandWindow::getLength(void);
+	long onCmdClose(FXObject*,FXSelector,void*);
+	void setText(const FXchar*);
+	void appendText(const FXchar* str);
+	void scrollToLastLine(void);
+	FXint getLength(void);
 };
 
 #endif
