@@ -2,8 +2,8 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.2/fx.h>
-#include <fox-1.2/fxkeys.h>
+#include <fox-1.4/fx.h>
+#include <fox-1.4/fxkeys.h>
 
 #include "DialogBox.h"
 
@@ -126,7 +126,7 @@ void DialogBox::show()
     }
 
     // Pop the window
-    FXTopWindow::show(PLACEMENT_OWNER);
+    FXTopWindow::show(PLACEMENT_CURSOR);
 }
 
 
