@@ -4,17 +4,14 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.2/fx.h>
-#include <fox-1.2/FXPNGIcon.h>
+#include <fox-1.4/fx.h>
+#include <fox-1.4/FXPNGIcon.h>
 
+#include "xfedefs.h"
 #include "File.h"
 #include "DirBox.h"
 #include "icons.h"
 
-// Root directory string
-#ifndef ROOTDIR
-#define ROOTDIR "/"
-#endif
 
 // Map
 FXDEFMAP(DirBox) DirBoxMap[]={
@@ -146,14 +143,14 @@ void DirBox::setDirectory(const FXString& pathname)
             directory=path;
             clearItems();
 
-            item=addItemFirst(NULL,ROOTDIR,foldericon,foldericon);
+            item=prependItem(NULL,ROOTDIR,foldericon,foldericon);
             part=1;
             while(1)
             {
                 string=directory.section(PATHSEP,part);
                 if(string.empty())
                     break;
-                item=addItemLast(item,string,foldericon,foldericon);
+                item=appendItem(item,string,foldericon,foldericon);
                 part++;
             }
             setCurrentItem(item);
