@@ -31,16 +31,13 @@
 // Time interval before expanding a folder (ms)
 #define EXPAND_INTERVAL		500
 
-extern FXbool ask_before_copy;
-
-
+// Global variables
 #if defined(linux)
 #define FSTAB_PATH "/etc/fstab"
 #define MTAB_PATH "/proc/mounts"
 extern FXStringDict* fsdevices;
 extern FXStringDict* mtdevices;
 extern FXStringDict* updevices;
-extern FXbool mount_warn;
 #endif
 
 
@@ -132,6 +129,7 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
     sortfunc=(FXTreeListSortFunc)ascendingCase;
     dropaction=DRAG_MOVE;
     counter=0;
+	prevSelItem=NULL;
 
 #if defined(linux)
 
@@ -403,7 +401,9 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
     FXbool showdialog=TRUE;
     File *f=NULL;
 
-    if(prevSelItem)
+    FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
+	
+	if(prevSelItem)
     {
         if(!isItemCurrent(prevSelItem))
             closeItem(prevSelItem);
@@ -1008,7 +1008,9 @@ long DirList::onUpdevicesRefresh(FXObject*,FXSelector,void*)
     struct stat statbuf;
     FXString mtstate;
 
-    FXStringDict* tmpdict = new FXStringDict();
+    FXbool mount_warn=getApp()->reg().readUnsignedEntry("OPTIONS","mount_warn",TRUE);
+	
+	FXStringDict* tmpdict = new FXStringDict();
     FILE *mtab=setmntent(MTAB_PATH,"r");
     if(mtab)
     {
