@@ -20,9 +20,10 @@
 #include "XFileExplorer.h"
 #include "MessageBox.h"
 
+// Refresh interval for the directory size (ms)
+#define DIRSIZE_INTERVAL 1000
 
 // Global variables
-extern FXbool confirm_del;
 extern FXString clipboard;
 extern FXuint clptype;
 extern FXMainWindow *mainWindow;
@@ -54,6 +55,7 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_SORT_REVERSE,DirPanel::onCmdSortReverse),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_HIDDEN,DirPanel::onCmdToggleHidden),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_TOGGLE_TREE,DirPanel::onCmdToggleTree),
+                                   FXMAPFUNC(SEL_TIMEOUT,DirPanel::ID_DIRSIZE_REFRESH,DirPanel::onCmdDirsizeRefresh),
 #if defined(linux)
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_MOUNT,DirPanel::onCmdMount),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_UMOUNT,DirPanel::onCmdMount),
@@ -69,14 +71,14 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_RENAME,DirPanel::onUpdMenu),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_DIR_DELETE,DirPanel::onUpdMenu),
                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_NEW_DIR,DirPanel::onUpdMenu),
-                                    FXMAPFUNC(SEL_UPDATE,DirPanel::ID_STATUS,DirPanel::onUpdStatus),
+                                   FXMAPFUNC(SEL_UPDATE,DirPanel::ID_TITLE,DirPanel::onUpdTitle),
                           		};
 
 // Object implementation 
 FXIMPLEMENT(DirPanel,FXVerticalFrame,DirPanelMap,ARRAYNUMBER(DirPanelMap))
 
 // Construct Directory Panel
-DirPanel::DirPanel(FXComposite *p,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+DirPanel::DirPanel(FXComposite *p, FXColor listbackcolor, FXColor listforecolor, FXuint opts, FXint x, FXint y, FXint w, FXint h):
         FXVerticalFrame(p,opts,x,y,w,h,0,0,0,0)
 {
 	// Create some icons
@@ -108,19 +110,22 @@ DirPanel::DirPanel(FXComposite *p,FXuint opts,FXint x,FXint y,FXint w,FXint h):
 	new FXLabel(packer,_("Folders"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X);
 
     list=new DirList(cont,this,ID_DIR_PANEL,LAYOUT_FILL_X|LAYOUT_FILL_Y|TREELIST_BROWSESELECT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|ICONLIST_BIG_ICONS);
+	list->setTextColor(listforecolor);
+	list->setBackColor(listbackcolor);
 
 	statusbar=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
-    statusbar->setTarget(this);
-    statusbar->setSelector(FXSEL(SEL_UPDATE,DirPanel::ID_STATUS));
     new FXToggleButton(statusbar,_("\tShow hidden folders (Ctrl-F5)"),_("\tHide hidden folders (Ctrl-F5)"),showhiddenicon,hidehiddenicon,this,
 	                   ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
     status=new FXLabel(statusbar,_("Status"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
+    status->setTarget(this);
+    status->setSelector(FXSEL(SEL_UPDATE,DirPanel::ID_TITLE));
 }
 
 
 // Destructor
 DirPanel::~DirPanel()
 {
+    getApp()->removeTimeout(this,ID_DIRSIZE_REFRESH);
 	delete attricon;
 	delete archicon;
 	delete sorticon;
@@ -147,6 +152,7 @@ DirPanel::~DirPanel()
 // Create X window
 void DirPanel::create()
 {
+    getApp()->addTimeout(this,ID_DIRSIZE_REFRESH,DIRSIZE_INTERVAL);
 	FXVerticalFrame::create();
 }
 
@@ -394,7 +400,8 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
 	FXString name=list->getItemText(item);
 	FXString pathname=list->getItemPathname((TreeItem*)item);	
 	FXString parentdir=FXFile::directory(pathname);
-	FXString archive="", cmd;
+	FXString cmd;
+	FXString archive=name;
 	
     static char history[ADD_TO_ARCH_HIST_SIZE][100];
     static int n=0;
@@ -410,10 +417,10 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
     dialog->CursorEnd();
     if(dialog->execute())
     {
-        archive=parentdir+PATHSEPSTRING+dialog->getText();
+        archive="\""+parentdir+PATHSEPSTRING+dialog->getText()+"\"";
 
         // Handle zip and bz2 archives
-        FXString ext=archive.rafter('.',1);
+        FXString ext=dialog->getText().rafter('.',1);
 		ext.lower();
 		if (ext=="zip")
             cmd="zip -r ";
@@ -427,7 +434,7 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
 			cmd="tar -Zcvf ";
 
 		// Archive command name
-		cmd+=archive+" "+"\""+name+"\"";
+		cmd=cmd+archive+" "+"\""+name+"\"";
 					
 		// File object
 		f=new File(this,_("Create archive"),ARCHIVE);
@@ -532,7 +539,8 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
         return 0;
     }
 
-    if(confirm_del)
+    FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
+	if(confirm_del)
     {
         FXPNGIcon icon(getApp(),delete_big);
 		FXString message=_("Delete folder ") + pathname + " ?";
@@ -630,8 +638,12 @@ long DirPanel::onCmdNewDir(FXObject*,FXSelector,void*)
 		dirname=dirpath+dialog->getText();		
         if(dirname!=dirpath)
         {
-			// Create the new dir
-			FXint ret=mkdir(dirname.text(),0755);
+			// Create the new dir according to the current umask
+			int mask;
+			mask=umask(0);
+			umask(mask);
+			// note that the umask value is in decimal (511 means octal 0777)
+			FXint ret=::mkdir(dirname.text(),511 & ~mask);
 			if (ret==-1)
 			{
          		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
@@ -842,8 +854,8 @@ long DirPanel::onUpdMenu(FXObject* o,FXSelector,void*)
 }
 
 
-// Update the status bar and the directory path name
-long DirPanel::onUpdStatus(FXObject* sender,FXSelector,void*)
+// Refresh the directory size in the status bar
+long DirPanel::onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*)
 {
 	unsigned long long dsize;
 	char buf[MAXPATHLEN+1], size[64];
@@ -859,11 +871,10 @@ long DirPanel::onUpdStatus(FXObject* sender,FXSelector,void*)
 		return 0;
 	}
 	
-	// Path name of the selected item
-	FXString path=list->getItemPathname(item);	
+	// Path name of the selected item (without trailing '/' except for the root path)
+	FXString path=::filePath(list->getItemPathname(item),"");
 
 	// Size of the files present in the directory
-	path=quote(path,FALSE);
 	strlcpy(buf,path.text(),path.length()+1);
 	dsize=dirsize(buf);
 
@@ -871,10 +882,34 @@ long DirPanel::onUpdStatus(FXObject* sender,FXSelector,void*)
 	snprintf(size,sizeof(size)-1,"%llu",dsize);
 	hsize=::hSize(size);
 
-	// Update the status label
+	// Refresh the status label
 	snprintf(buf,sizeof(buf)-1,_("%s"),hsize.text());
 	status->setText(buf);
 
+    // Reset timer again
+    getApp()->addTimeout(this,ID_DIRSIZE_REFRESH,DIRSIZE_INTERVAL);
+
+    return 1;
+}
+
+
+// Update the path name in the Window title
+long DirPanel::onUpdTitle(FXObject* sender,FXSelector,void*)
+{
+	
+	// Name of the current selected item
+	TreeItem* item=(TreeItem*)list->getCurrentItem();
+	
+	// There is no selected item
+	if (item==NULL)
+	{
+		mainWindow->setTitle("Xfe - ");
+		return 0;
+	}
+	
+	// Path name of the selected item
+	FXString path=list->getItemPathname(item);	
+
 	// Update the path in the window title
 	if(getuid()==0)
 		mainWindow->setTitle("Xfe (root) - " + path);
