@@ -33,7 +33,7 @@ protected:
     FXLabel	*status;
 
 public:
-DirPanel(FXComposite *p,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0),FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
     DirPanel()
     {}
     virtual void create();
@@ -58,8 +58,9 @@ DirPanel(FXComposite *p,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 		ID_CUT_CLP,
 		ID_PASTE_CLP,
         ID_TOGGLE_TREE,
-		ID_STATUS,
+		ID_TITLE,
 		ID_SORT_REVERSE,
+		ID_DIRSIZE_REFRESH,
 #if defined(linux)
         ID_MOUNT,
         ID_UMOUNT,
@@ -85,10 +86,12 @@ public:
 	long onUpdPaste(FXObject* o,FXSelector,void*);
 	long onCmdDirectory(FXObject*,FXSelector,void* ptr);
 	long onCmdToggleTree(FXObject* sender,FXSelector sel,void* ptr);
+	long onCmdDirsizeRefresh(FXObject* sender,FXSelector,void*);
 	long onUpdToggleTree(FXObject* sender,FXSelector sel,void* ptr);
 	long onUpdMount(FXObject* o,FXSelector sel,void*);
 	long onUpdUnmount(FXObject* o,FXSelector sel,void*);
 	long onUpdMenu(FXObject* o,FXSelector,void*);
+	long onUpdTitle(FXObject* sender,FXSelector,void*);
 	long onUpdStatus(FXObject* sender,FXSelector,void*);
 	long onExpand(FXObject*,FXSelector,void* ptr);
 	long onCmdSortReverse(FXObject*,FXSelector,void* ptr);
