@@ -1,6 +1,8 @@
 // File management functions taken from the Fox library
 // and modified to add a progress dialog 
-// Some helper functions are also added to get large files support 
+// Some helper functions are also added to get large files support
+// Also supports a timeout on the stat and lstat function (this is the reason
+// why some standard FOX function cannot be used and are rewritten here)
 
 #include "config.h"
 #include "i18n.h"
@@ -34,13 +36,15 @@
 #include "MessageBox.h"
 #include "CommandWindow.h"
 
+// Global variables
+extern FXMainWindow *mainWindow;
 #if defined(linux)
 extern FXStringDict* mtdevices;
 extern FXStringDict* updevices;
-extern FXbool mount_messages;
 #endif
 
-
+// Timeout for stat functions (seconds)
+#define TIMEOUT 5
 
 // Delay before the progress bar should be shown (ms)
 #define SHOW_PBAR_DELAY 1000
@@ -48,65 +52,6 @@ extern FXbool mount_messages;
 // Progress dialog width
 #define PDIALOG_WIDTH 150
 
-// Global variables
-extern FXMainWindow *mainWindow;
-extern FXbool confirm_overwrite;
-
-// Timeout for stat functions (seconds)
-#define TIMEOUT 5
-
-// Safe strcpy function (Public domain, by C.B. Falconer)
-// The destination string is always null terminated
-size_t strlcpy(char *dst, const char *src, size_t sz)
-{
-	const char *start = src;
-
-	if (src && sz--)
-	{
-		while ((*dst++ = *src))
-			if (sz--)
-				src++;
-			else
-		 	{
-            	*(--dst) = '\0';
-            	break;
-         	}
-   	}
-   	if (src)
-   	{
-      	while (*src++)
-			continue;
-      	return src - start - 1;
-   	}
-   	else if (sz)
-		*dst = '\0';
-	return 0;
-}
-
-
-// Safe strcat function (Public domain, by C.B. Falconer)
-// The destination string is always null terminated
-size_t strlcat(char *dst, const char *src, size_t sz)
-{
-   char  *start = dst;
-
-   while (*dst++)      // assumes sz >= strlen(dst)
-      if (sz)
-	  	sz--;          // i.e. well formed string
-   dst--;
-   return dst - start + strlcpy(dst, src, sz);
-}
-
-
-// To test if two strings are equal (strcmp replacement, thanks to Francesco Abbate)
-int streq(const FXchar *a, const FXchar *b)
-{
-	if (a == NULL || b == NULL)
-		return 0;
-	return (strcmp(a, b) == 0);
-}
-
-
 
 // Replacement of the stat function with a timeout
 int statout(const char *filename, struct stat *buf)
@@ -148,6 +93,7 @@ int statout(const char *filename, struct stat *buf)
 						if (difftime(t,t0)>TIMEOUT)
 						{
 							kill(pid,SIGKILL);
+							waitpid(pid,&ret,WNOHANG); // Avoids zombies
 							return -1;
 						}
 					}
@@ -220,6 +166,7 @@ int lstatout(const char *filename, struct stat *buf)
 						if (difftime(t,t0)>TIMEOUT)
 						{
 							kill(pid,SIGKILL);
+							waitpid(pid,&ret,WNOHANG); // Avoids zombies
 							return -1;
 						}
 					}
@@ -286,6 +233,7 @@ int mtlstat(const char *filename, struct stat *buf)
 				if (difftime(t,t0)>TIMEOUT)
 				{
 					kill(pid,SIGKILL);
+					waitpid(pid,&ret,WNOHANG); // Avoids zombies
 					return -1;
 				}
 			}
@@ -306,36 +254,100 @@ int mtlstat(const char *filename, struct stat *buf)
 #endif
 
 
+// Safe strcpy function (Public domain, by C.B. Falconer)
+// The destination string is always null terminated
+// Size sz must be equal to strlen(src)+1
+size_t strlcpy(char *dst, const char *src, size_t sz)
+{
+	const char *start = src;
+
+	if (src && sz--)
+	{
+		while ((*dst++ = *src))
+			if (sz--)
+				src++;
+			else
+		 	{
+            	*(--dst) = '\0';
+            	break;
+         	}
+   	}
+   	if (src)
+   	{
+      	while (*src++)
+			continue;
+      	return src - start - 1;
+   	}
+   	else if (sz)
+		*dst = '\0';
+	return 0;
+}
+
+
+// Safe strcat function (Public domain, by C.B. Falconer)
+// The destination string is always null terminated
+size_t strlcat(char *dst, const char *src, size_t sz)
+{
+   char  *start = dst;
+
+   while (*dst++)      // assumes sz >= strlen(dst)
+      if (sz)
+	  	sz--;          // i.e. well formed string
+   dst--;
+   return dst - start + strlcpy(dst, src, sz);
+}
+
+
+// To test if two strings are equal (strcmp replacement, thanks to Francesco Abbate)
+int streq(const FXchar *a, const FXchar *b)
+{
+	if (a == NULL || b == NULL)
+		return 0;
+	return (strcmp(a, b) == 0);
+}
+
+
+// Convert a string to lower cases and returns the string size
+void strlow ( char *str )
+{
+    while ( *str )
+    {
+        *str = tolower ( *str );
+        ++str;
+    }
+} 
+
+
 // Obtain the non recursive size of a directory
-unsigned long long dirsize(char *path)
+unsigned long long dirsize(const char *path)
 {
     DIR *dp;
 	struct dirent *dirp;
 	struct stat statbuf;
 	char buf[MAXPATHLEN];
 	unsigned long long dsize=0;
-	int l, ret;
+	int ret;
 			
 	if((dp=opendir(path))==NULL)
         return 0;
 	
-	l=strlen(path);
-	if (l>0 && path[l-1]=='/')
-		path[l-1]='\0';
-
 	while((dirp=readdir(dp)))
     {
         if ( ::streq(dirp->d_name, ".")||::streq(dirp->d_name, "..") )
             continue;
 		
-		snprintf(buf,sizeof(buf)-1,"%s/%s",path,dirp->d_name);
+		if (::streq(path,ROOTDIR))
+			snprintf(buf,sizeof(buf)-1,"%s%s",path,dirp->d_name);
+		else
+			snprintf(buf,sizeof(buf)-1,"%s/%s",path,dirp->d_name);
 		
 #if defined(linux)
-		if (mtdevices->find(buf))
-			ret=lstatout(buf,&statbuf);
-		else
+		// Mount points are not processed to improve performances 
+		if(mtdevices->find(buf))
+			continue;
 #endif
-			ret=lstat(buf,&statbuf);
+		
+		ret=lstatout(buf,&statbuf);
 		if(ret>=0)
 		{
 			if(!S_ISDIR(statbuf.st_mode))
@@ -348,7 +360,7 @@ unsigned long long dirsize(char *path)
 }
 
 // Obtain the recursive size of a directory
-unsigned long long dirpath( char *path)
+unsigned long long pathsize(const char *path)
 {
 	struct stat statbuf;
 	struct dirent *dirp;
@@ -357,12 +369,7 @@ unsigned long long dirpath( char *path)
 	unsigned long long dsize;
 	int ret;
 
-#if defined(linux)
-	if (mtdevices->find(path))
-		ret=lstatout(path,&statbuf);
-	else
-#endif
-		ret=lstat(path,&statbuf);
+	ret=lstatout(path,&statbuf);
 	if(ret<0)
         return 0;
     dsize = (unsigned long long) statbuf.st_size;
@@ -371,7 +378,7 @@ unsigned long long dirpath( char *path)
 	if(!S_ISDIR(statbuf.st_mode))
         return dsize;
     
-	ptr=path + strlen(path);
+	ptr=(char*)path + strlen(path);
     if(ptr[-1]!='/')
     {
         *ptr++='/';
@@ -388,7 +395,7 @@ unsigned long long dirpath( char *path)
         strlcpy(ptr, dirp->d_name, strlen(dirp->d_name)+1);
 		
 		// Recursive call
-        dsize+=dirpath(path);
+        dsize+=pathsize(path);
     }
 	
     ptr[-1]='\0'; // ??
@@ -509,83 +516,6 @@ FXString stampname(const FXString filename)
 }
 
 
-// Enquote filename to make it safe for shell
-// (the function provided by Fox seems to be buggy??)
-FXString quote(const FXString& file,FXbool forcequotes)
-{
-	FXString result;
-	register FXint i,c;
-	for(i=0; (c=file[i])!='\0'; i++)
-	{
-    	switch(c)
-		{
-      	case '"':              // Quote needs to be escaped
-        	result+="\\\"";
-        break;
-      	case '\\':              // Backspace needs to be escaped, of course
-        	result+="\\\\";
-        break;
-      	case '#':
-      	case '~':
-        	if(i) goto noquote;   // Only quote if at begin of filename
-      	case '!':               // Special in csh
-      	case '\'':
-      	case '$':               // Variable substitution
-      	case '&':
-      	case '(':
-      	case ')':
-      	case ';':
-      	case '<':               // Redirections, pipe
-      	case '>':
-      	case '|':
-      	case '`':               // Command substitution
-      	case '^':               // Special in sh
-      	case '*':               // Wildcard characters
-      	case '?':
-      	case '[':
-      	case ']':
-      	case '\t':              // White space
-      	case '\n':
-      	case ' ':
-        	forcequotes=TRUE;
-      	default:                // Normal characters just added
-			noquote:result+=c;
-        break;
-		}
-	}
-	if(forcequotes) return "\""+result+"\"";
-	return result;
-}
-
-// Decode filename to get original again
-FXString dequote(const FXString& file)
-{
-	FXString result;
-	register FXint i,c;
-	i=0;
-	while((c=file[i])!='\0' && isspace((FXuchar)c)) i++;
-  	if(file[i]=='\"')
-	{
-    	i++;
-    	while((c=file[i])!='\0' && c!='\"')
-		{
-      		if(c=='\\' && file[i+1]!='\0') c=file[++i];
-      		result+=c;
-      		i++;
-      	}
-    }
-	else
-	{
-    	while((c=file[i])!='\0' /*&& !isspace((FXuchar)c)*/)
-		{
-      		if(c=='\\' && file[i+1]!='\0') c=file[++i];
-      		result+=c;
-      		i++;
-      	}
-    }
-  	return result;
-}
-
 // Test if a directory is empty
 // Return -1 if not a directory, 1 if empty and 0 if not empty
 FXint isEmptyDir(const FXString directory)
@@ -628,12 +558,40 @@ FXbool isFile(const FXString& file)
   	return !file.empty() && (statout(file.text(),&status)==0) && S_ISREG(status.st_mode);
 }
 
+// Check if current user is member of gid
+// (thanks to Armin Buehler <abuehler@users.sourceforge.net>)
+FXbool isGroupMember(gid_t gid)
+{
+	static long ngroups = 0;
+	static gid_t *gids = NULL;
+	long i;
+
+	// First call : initialization of the number of supplementary groups and the group list
+	if (ngroups == 0)
+	{
+		ngroups = getgroups(0, gids);
+		gids = new gid_t[ngroups];
+		getgroups(ngroups, gids);
+	}
+	if (ngroups == 0)
+		return FALSE;
+
+	// Check if the group id is contained within the group list
+	i = ngroups;
+	while (i--)
+	{
+		if (gid == gids[i])
+			return TRUE;
+	}
+	return FALSE;
+}
+
 // Check if the file or the link refered file is writable
+// Doesn't use the standard FOX function because of the stat timeout 
 FXbool isWritable(const FXString& file)
 {
   	struct stat status;
 	FXuint uid=getuid();
-	FXuint gid=getgid();
 	
 	// File exists and can be stated
 	if (!file.empty() && (statout(file.text(),&status)==0))
@@ -653,7 +611,7 @@ FXbool isWritable(const FXString& file)
 				return FALSE;
 		}
 		// We are in the group of the file
-		else if (gid==status.st_gid)
+		else if (isGroupMember(status.st_gid))
 		{
 			// The file is writable
 			if (status.st_mode & S_IWGRP)
@@ -678,11 +636,11 @@ FXbool isWritable(const FXString& file)
 }
 
 // Check if the file or the link itself is writable
+// Doesn't use the standard FOX function because of the stat timeout 
 FXbool isLWritable(const FXString& file)
 {
   	struct stat status;
 	FXuint uid=getuid();
-	FXuint gid=getgid();
 	
 	// File or link exists and can be stated
 	if (!file.empty() && (lstatout(file.text(),&status)==0))
@@ -702,7 +660,7 @@ FXbool isLWritable(const FXString& file)
 				return FALSE;
 		}
 		// We are in the group of the file or link
-		else if (gid==status.st_gid)
+		else if (isGroupMember(status.st_gid))
 		{
 			// The file or link is writable
 			if (status.st_mode & S_IWGRP)
@@ -728,11 +686,11 @@ FXbool isLWritable(const FXString& file)
 
 // Check if the file or the link refered file is readable AND executable
 // Function used to test if we can enter a directory
+// Doesn't use the standard FOX function because of the stat timeout 
 FXbool isReadExecutable(const FXString& file)
 {
   	struct stat status;
 	FXuint uid=getuid();
-	FXuint gid=getgid();
 	
 	// File exists and can be stated
 	if (!file.empty() && (statout(file.text(),&status)==0))
@@ -752,7 +710,7 @@ FXbool isReadExecutable(const FXString& file)
 				return FALSE;
 		}
 		// We are in the group of the file
-		else if (gid==status.st_gid)
+		else if (isGroupMember(status.st_gid))
 		{
 			// The file is readable and executable
 			if ((status.st_mode & S_IRGRP) && (status.st_mode & S_IXGRP))
@@ -911,6 +869,8 @@ File::File(FXWindow *owner, FXString title, const unsigned int operation):FXDial
     		downlabel=NULL;
 	}
 	
+	FXbool confirm_overwrite=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_overwrite",TRUE);
+	
 	// Initialize the overwrite flags
 	if (confirm_overwrite)
 	{
@@ -944,19 +904,17 @@ void File::create()
 // Force check of timeout for progress dialog (to avoid latency problems)
 int File::checkTimeout(void)
 {
-	timeval now;	
 	if (getApp()->hasTimeout(this,File::ID_TIMEOUT))
 	{
 		if (getApp()->remainingTimeout(this,File::ID_TIMEOUT)==0)
-			if (now.tv_sec>0)
-			{
-				getApp()->removeTimeout(this,File::ID_TIMEOUT);
-				if (allowPdialog)
-					show(PLACEMENT_OWNER);
-				getApp()->forceRefresh();
-				getApp()->flush();
-				return 1;
-			}
+		{
+			getApp()->removeTimeout(this,File::ID_TIMEOUT);
+			if (allowPdialog)
+				show(PLACEMENT_OWNER);
+			getApp()->forceRefresh();
+			getApp()->flush();
+			return 1;
+		}
 	}
 	return 0;
 }
@@ -1980,6 +1938,8 @@ int File::archive(const FXString name, const FXString cmd)
 #if defined(linux)
 int File::mount(const FXString dir, const FXString msg, const FXString cmd, const unsigned int op)
 {
+	FXbool mount_messages=getApp()->reg().readUnsignedEntry("OPTIONS","mount_messages",TRUE);
+
 	// Show progress dialog (no timer here)
 	show(PLACEMENT_OWNER);
 	getApp()->forceRefresh();
