@@ -2,9 +2,9 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox-1.2/fx.h>
-#include <fox-1.2/fxkeys.h>
-#include <fox-1.2/FXPNGIcon.h>
+#include <fox-1.4/fx.h>
+#include <fox-1.4/fxkeys.h>
+#include <fox-1.4/FXPNGIcon.h>
 
 #include "File.h"
 #include "FileList.h"
@@ -42,6 +42,7 @@ static const FXchar allfiles[]="All Files (*)";
 FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
         FXPacker(p,opts,x,y,w,h)
 {
+	FXAccelTable *table=getShell()->getAccelTable();
     target=tgt;
     message=sel;
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING, 0,0);
@@ -55,8 +56,7 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
 
   	filefilter=new FXComboBox(filterframe,10,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
   	filefilter->setNumVisible(4);
-
-
+	
     readonly=new FXCheckButton(filterframe,_("Read Only"),NULL,0,ICON_BEFORE_TEXT|JUSTIFY_LEFT|LAYOUT_CENTER_Y);
     cancel=new FXButton(fields,_("&Cancel"),NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
     FXHorizontalFrame *frame=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
@@ -70,6 +70,8 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     workicon=new FXPNGIcon(getApp(),work);
     shownicon=new FXPNGIcon(getApp(),hidehidden);
     hiddenicon=new FXPNGIcon(getApp(),showhidden);
+	showthumbicon=new FXPNGIcon(getApp(),showthumb);
+	hidethumbicon=new FXPNGIcon(getApp(),hidethumb);
     dirbox=new DirBox(buttons,this,ID_DIRTREE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,160,0);
 	dirbox->setNumVisible(5);
     new FXFrame(buttons,LAYOUT_FIX_WIDTH,0,0,4,1);
@@ -80,7 +82,16 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     new FXButton(buttons,_("\tShow icons\tDisplay folder with big icons."),iconsicon,filebox,FileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tShow details\tDisplay detailed folder listing."),detailicon,filebox,FileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXToggleButton(buttons,_("\tShow hidden files\tShow hidden files and folders."),_("\tHide hidden Files\tHide hidden files and folders."),hiddenicon,shownicon,filebox,FileList::ID_TOGGLE_HIDDEN,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXToggleButton(buttons,_("\tShow thumbnails"),_("\tHide thumbnails"),showthumbicon,hidethumbicon,filebox,FileList::ID_TOGGLE_THUMBNAILS,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     readonly->hide();
+  	if(table)
+	{
+    	table->addAccel(MKUINT(KEY_BackSpace,0),this,FXSEL(SEL_COMMAND,ID_DIRECTORY_UP));
+    	table->addAccel(MKUINT(KEY_h,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_HOME));
+    	table->addAccel(MKUINT(KEY_w,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_WORK));
+    	table->addAccel(MKUINT(KEY_a,CONTROLMASK),filebox,FXSEL(SEL_COMMAND,FileList::ID_SELECT_ALL));
+    	table->addAccel(MKUINT(KEY_i,CONTROLMASK),filebox,FXSEL(SEL_COMMAND,FileList::ID_DESELECT_ALL));
+    }
     setSelectMode(SELECTFILE_ANY);    // For backward compatibility, this HAS to be the default!
     setPatternList(allfiles);
     setDirectory(FXFile::getCurrentDirectory());
@@ -217,7 +228,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
     {
 
         // Is directory?
-        if(isDirectory(path))
+        if(::isDirectory(path))
         {
 
             // In directory mode:- we got our answer!
@@ -239,7 +250,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         FXString dir=FXFile::directory(path);
 
         // In file mode, directory part of path should exist
-        if(isDirectory(dir))
+        if(::isDirectory(dir))
         {
 
             // In any mode, existing directory part is good enough
@@ -253,7 +264,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
             // In existing mode, the whole filename must exist and be a file
             else if(selectmode==SELECTFILE_EXISTING)
             {
-                if(isFile(path))
+                if(::isFile(path))
                 {
                     if(tgt)
                         tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
@@ -291,7 +302,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         }
 
         // Go up to the lowest directory which still exists
-        while(!FXFile::isTopDirectory(dir) && !isDirectory(dir))
+        while(!FXFile::isTopDirectory(dir) && !::isDirectory(dir))
             dir=FXFile::upLevel(dir);
 
         // Switch as far as we could go
@@ -299,7 +310,6 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
         filebox->setDirectory(dir);
 
         // Put the tail end back for further editing
-        FXASSERT(dir.length()<=path.length());
         if(ISPATHSEP(path[dir.length()]))
             path.remove(0,dir.length()+1);
         else
@@ -758,6 +768,15 @@ void FileSelector::load(FXStream& store)
 // Cleanup; icons must be explicitly deleted
 FileSelector::~FileSelector()
 {
+	FXAccelTable *table=getShell()->getAccelTable();
+	if(table)
+	{
+    	table->removeAccel(MKUINT(KEY_BackSpace,0));
+    	table->removeAccel(MKUINT(KEY_h,CONTROLMASK));
+    	table->removeAccel(MKUINT(KEY_w,CONTROLMASK));
+    	table->removeAccel(MKUINT(KEY_a,CONTROLMASK));
+    	table->removeAccel(MKUINT(KEY_i,CONTROLMASK));
+    }
     delete updiricon;
     delete listicon;
     delete detailicon;
@@ -1003,7 +1022,7 @@ FXString FileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,con
     if(opendialog.execute())
     {
         filename=opendialog.getFilename();
-        if(isFile(filename))
+        if(::isFile(filename))
             return filename;
     }
     return FXString::null;
@@ -1048,7 +1067,7 @@ FXString FileDialog::getOpenDirectory(FXWindow* owner,const FXString& caption,co
     if(dirdialog.execute())
     {
         dirname=dirdialog.getFilename();
-        if(isDirectory(dirname))
+        if(::isDirectory(dirname))
             return dirname;
     }
     return FXString::null;
