@@ -4,15 +4,16 @@
 // Registers stuff to know about the extension
 struct FileAssoc
 {
-    FXString   command;           /// Command to execute
-    FXString   extension;         /// Full extension name
-    FXString   mimetype;          /// Mime type name
-    FXIcon    *bigicon;           /// Big normal icon
-    FXIcon    *bigiconopen;       /// Big open icon
-    FXIcon    *miniicon;          /// Mini normal icon
-    FXIcon    *miniiconopen;      /// Mini open icon
-    FXDragType dragtype;          /// Registered drag type
-    FXuint     flags;             /// Flags
+    FXString   key;               // Key extension (ex: zip, cpp, ...)	
+	FXString   command;           // Command to execute
+    FXString   extension;         // Full extension name (ex: ZIP Archive, C++ Source, ...)
+    FXString   mimetype;          // Mime type name
+    FXIcon    *bigicon;           // Big normal icon
+    FXIcon    *bigiconopen;       // Big open icon
+    FXIcon    *miniicon;          // Mini normal icon
+    FXIcon    *miniiconopen;      // Mini open icon
+    FXDragType dragtype;          // Registered drag type
+    FXuint     flags;             // Flags
 };
 
 
@@ -90,7 +91,7 @@ public:
 };
 
 
-/**
+/*
 * The File Association dictionary associates a file extension
 * with a FileAssoc record which contains command name, mime type,
 * icons, and other information about the file type.
@@ -103,7 +104,7 @@ class FXAPI FileDict : public FXDict
 private:
     FXApp        *app;            // Application object
     FXSettings   *settings;       // Settings database where to get bindings
-    IconDict   *icons;          // Icon table
+    IconDict   *icons;            // Icon table
 protected:
     FileDict()
     {}
@@ -124,19 +125,19 @@ public:
     static const FXchar defaultFileBinding[];
 public:
 
-    /**
+    /*
     * Construct a dictionary mapping file-extension to file associations,
     * using the application registry settings as a source for the bindings.
     */
     FileDict(FXApp* a);
 
-    /**
+    /*
     * Construct a dictionary mapping file-extension to file associations,
     * using the specified settings database as a source for the bindings.
     */
     FileDict(FXApp* a,FXSettings* db);
 
-    /// Get application
+    // Get application
     FXApp* getApp() const
     {
         return app;
@@ -148,7 +149,7 @@ public:
     // Return current icon search path
     FXString getIconPath() const;
 
-    /**
+    /*
     * Replace file association.
     * The new association is written into the settings database under the
     * FILETYPES section; the format of the association is as follows:
@@ -171,8 +172,7 @@ public:
     FileAssoc* replace(const FXchar* ext,const FXchar* str);
 
     // Remove file association
-    FileAssoc* remove
-        (const FXchar* ext);
+    FileAssoc* remove (const FXchar* ext);
 
     // Find file association already in dictionary
     FileAssoc* find(const FXchar* ext)
@@ -183,7 +183,7 @@ public:
     // Find file association from registry
     FileAssoc* associate(const FXchar* key);
 
-    /**
+    /*
     * Determine binding for the given file.
     * The default implementation tries the whole filename first,
     * then tries the extensions.
@@ -199,7 +199,7 @@ public:
     */
     virtual FileAssoc* findFileBinding(const FXchar* pathname);
 
-    /**
+    /*
     * Find directory binding from registry.
     * The default implementation tries the whole pathname first,
     * then tries successively smaller parts of the path.
@@ -215,7 +215,7 @@ public:
     */
     virtual FileAssoc* findDirBinding(const FXchar* pathname);
 
-    /**
+    /*
     * Determine binding for the given executable.
     * The default implementation returns the fallback binding associated with
     * the key "defaultexecbinding".
