@@ -15,6 +15,7 @@
 #include <mntent.h>
 #endif
 
+#include "xfedefs.h"
 #include "icons.h"
 #include "FileList.h"
 #include "InputDialog.h"
@@ -23,22 +24,6 @@
 #include "MessageBox.h"
 
 
-
-// Root directory string
-#ifndef ROOTDIR
-#define ROOTDIR "/"
-#endif
-
-// Path separator
-#ifndef PATHSEPSTRING
-#define PATHSEPSTRING "/"
-#endif
-
-// Maximum length of a file name
-#ifndef MAXPATHLEN
-#define MAXPATHLEN 1024
-#endif
-
 // Minimum file name size in detailed view
 #ifndef MIN_NAME_SIZE
 #define MIN_NAME_SIZE 75
@@ -58,7 +43,6 @@
 #define HASH1(x,n) (((unsigned int)(x)*13)%(n))           // Probe Position [0..n-1]
 #define HASH2(x,n) (1|(((unsigned int)(x)*17)%((n)-1)))   // Probe Distance [1..n-1]
 
-extern FXbool ask_before_copy;
 
 #if defined(linux)
 #define FSTAB_PATH "/etc/fstab"
@@ -69,7 +53,6 @@ FXStringDict* updevices=NULL; // Responding devices
 #endif
 
 
-
 #define SELECT_MASK   (ICONLIST_EXTENDEDSELECT|ICONLIST_SINGLESELECT|ICONLIST_BROWSESELECT|ICONLIST_MULTIPLESELECT)
 
 
@@ -80,6 +63,7 @@ FXStringDict* updevices=NULL; // Responding devices
 #define SIDE_SPACING             4    // Left or right spacing between items
 #define DETAIL_TEXT_SPACING      2    // Spacing between text and icon in detail icon mode
 
+
 void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h) const
 {
     register FXHeader *header=list->getHeader();
@@ -152,6 +136,7 @@ void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXi
     }
 }
 
+
 // Object implementation
 FXIMPLEMENT(FileItem,FXIconItem,NULL,0)
 
@@ -212,16 +197,16 @@ FXIMPLEMENT(FileList,FXIconList,FileListMap,ARRAYNUMBER(FileListMap))
 
 
 // For serialization
-FileList::FileList(){
-  flags|=FLAG_ENABLED|FLAG_DROPTARGET;
-  sortfunc=ascendingCase;
-  associations=NULL;
-  list=NULL;
-  timestamp=0;
-  associations=NULL;
-  dropaction=DRAG_MOVE;
-  counter=0;
-  };
+FileList::FileList()
+{
+	flags|=FLAG_ENABLED|FLAG_DROPTARGET;
+	sortfunc=ascendingCase;
+	associations=NULL;
+	list=NULL;
+	timestamp=0;
+	dropaction=DRAG_MOVE;
+	counter=0;
+};
 
 
 // File List
@@ -260,7 +245,9 @@ FileList::FileList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
     mini_pipe=new FXPNGIcon(getApp(),minipipe);
     big_link=new FXPNGIcon(getApp(),biglink);
     mini_link=new FXPNGIcon(getApp(),minilink);
-    big_harddisk=new FXPNGIcon(getApp(),bigharddisk);
+	big_brokenlink=new FXPNGIcon(getApp(),bigbrokenlink);
+    mini_brokenlink=new FXPNGIcon(getApp(),minibrokenlink);
+	big_harddisk=new FXPNGIcon(getApp(),bigharddisk);
     mini_harddisk=new FXPNGIcon(getApp(),harddisk);
     big_nfs=new FXPNGIcon(getApp(),bignfsdrive);
     mini_nfs=new FXPNGIcon(getApp(),nfsdrive);
@@ -284,7 +271,6 @@ FileList::FileList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
     list=NULL;
 	displaythumbnails=FALSE;
 
-
 #if defined(linux)
 
 	// Initialize the fsdevices, mtdevices and updevices lists
@@ -387,6 +373,8 @@ void FileList::create()
     big_harddisk->create();
     mini_harddisk->create();
     big_link->create();
+    mini_brokenlink->create();
+    big_brokenlink->create();
     mini_link->create();
     big_nfs->create();
     mini_nfs->create();
@@ -517,7 +505,9 @@ long FileList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
     FXbool showdialog=TRUE;
     File *f=NULL;
 
-    if(prevIndex!=-1)
+    FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
+	
+	if(prevIndex!=-1)
     {
         setItemMiniIcon(prevIndex,mini_folder);
         setItemBigIcon(prevIndex,big_folder);
@@ -556,11 +546,11 @@ long FileList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
 			num=num-1;
 
         // File object
-        if (dropaction==DRAG_COPY)
+		if (dropaction==DRAG_COPY)
             f=new File(this,_("File copy"),COPY);
         else if (dropaction==DRAG_MOVE)
-            f=new File(this,_("File move"),MOVE);
-        else if ((dropaction==DRAG_LINK) && (num==1))
+				f=new File(this,_("File move"),MOVE);
+		else if ((dropaction==DRAG_LINK) && (num==1))
             f=new File(this,_("File symlink"),SYMLINK);
         else if ((dropaction==DRAG_LINK) && (num>1))
 		{
@@ -759,6 +749,11 @@ long FileList::onDragged(FXObject* sender,FXSelector sel,void* ptr)
         action=DRAG_MOVE;
 	if((event->state&CONTROLMASK) && (event->state&SHIFTMASK))
 		action=DRAG_LINK;
+	
+	// If source directory is read-only, convert move action to copy
+	if (!::isWritable(orgdirectory) && (action==DRAG_MOVE))
+		action=DRAG_COPY;
+	
     handleDrag(event->root_x,event->root_y,action);
     if(didAccept()!=DRAG_REJECT)
     {
@@ -883,7 +878,7 @@ long FileList::onUpdHideHidden(FXObject* sender,FXSelector,void*)
 // Move up one level
 long FileList::onCmdDirectoryUp(FXObject*,FXSelector,void*)
 {
-    setDirectory(FXFile::upLevel(directory));
+	setDirectory(FXFile::upLevel(directory));
     return 1;
 }
 
@@ -1156,6 +1151,9 @@ long FileList::onUpdSortCase(FXObject* sender,FXSelector,void* ptr)
 }
 
 
+
+
+
 // Clicked header button
 long FileList::onCmdHeader(FXObject*,FXSelector,void* ptr)
 {
@@ -1739,7 +1737,7 @@ FXString FileList::getCurrentFile() const
 // Set directory being displayed
 void FileList::setDirectory(const FXString& pathname)
 {
-    // FIXME notify argument?
+	// FIXME notify argument?
     if(!pathname.empty())
     {
         FXString path=FXFile::absolute(directory,pathname);
@@ -1752,7 +1750,7 @@ void FileList::setDirectory(const FXString& pathname)
             list=NULL;
             scan(TRUE);
         }
-    }
+    }	
 }
 
 
@@ -2081,7 +2079,14 @@ fnd:          	*pn=item;
                 	mini=mini_exec;
                 	extension+=_("Executable");
                 	if(associations)
-                		fileassoc=associations->findFileBinding(pathname.text());
+					{
+						fileassoc=associations->findFileBinding(pathname.text());					
+						
+						// In some special cases where the file is executable and its file name
+						// is equal to the short extension (ex: zip, cc, ...) we don't want to use the association
+						if ( fileassoc && (name==fileassoc->key) )
+							fileassoc=NULL;
+					}					
                 }
                 else
                 {
@@ -2093,9 +2098,9 @@ fnd:          	*pn=item;
                 }
 
                 // If association is found, use it
-				if(fileassoc)
-				{
-                	// If it is a link, modify the extension
+				if (fileassoc)
+				{														
+					// If it is a link, modify the extension
                 	if(islink)
                 	{
                     	// If it is a broken link
@@ -2249,8 +2254,18 @@ fnd:          	*pn=item;
                 // Symbolic links have a specific icon
                 if (islink)
                 {
-                	item->bigIcon=big_link;
-                	item->miniIcon=mini_link;
+                	
+					// Broken links
+					if (statout(pathname.text(),&info)!=0)
+					{
+						item->bigIcon=big_brokenlink;
+						item->miniIcon=mini_brokenlink;	
+					}
+					else
+					{
+						item->bigIcon=big_link;
+						item->miniIcon=mini_link;
+					}
                 }
                 // Create item
                 if(id())
@@ -2420,6 +2435,8 @@ FileList::~FileList()
     delete mini_bdev;
     delete big_link;
     delete mini_link;
+    delete big_brokenlink;
+    delete mini_brokenlink;
     delete big_harddisk;
     delete mini_harddisk;
     delete big_nfs;
