@@ -12,22 +12,22 @@ class FXAPI FileItem : public FXIconItem
     FXDECLARE(FileItem)
     friend class FileList;
 protected:
-    FileAssoc  *assoc;                      /// File association record
+    FileAssoc  *assoc;                      // File association record
 	FileItem   *link;                   	// Link to next item
-    unsigned long long size;                /// File size
-    FXTime        date;                     /// File time
+    unsigned long long size;                // File size
+    FXTime        date;                     // File time
 protected:
     FileItem():assoc(NULL),link(NULL),size(0),date(0)
     {}
 protected:
     enum{
-        FOLDER     = 64,                        /// Directory item
-        EXECUTABLE = 128,                       /// Executable item
-        SYMLINK    = 256,                       /// Symbolic linked item
-        CHARDEV    = 512,                       /// Character special item
-        BLOCKDEV   = 1024,                      /// Block special item
-        FIFO       = 2048,                      /// FIFO item
-        SOCK       = 4096                       /// Socket item
+        FOLDER     = 64,                        // Directory item
+        EXECUTABLE = 128,                       // Executable item
+        SYMLINK    = 256,                       // Symbolic linked item
+        CHARDEV    = 512,                       // Character special item
+        BLOCKDEV   = 1024,                      // Block special item
+        FIFO       = 2048,                      // FIFO item
+        SOCK       = 4096                       // Socket item
     };
 public:
     // Constructor
@@ -122,12 +122,12 @@ protected:
 	FXbool		ignorecase;				// Case sensitivity for file name sorting
 	FXbool		allowrefresh;			// Allow or disallow periodic refresh
 	FXbool		displaythumbnails;		// Display thumbnails
-    FXIcon      *big_folder;            // Big folder icon
-    FXIcon      *mini_folder;           // Mini folder icon
-    FXIcon      *big_doc;               // Big document icon
-    FXIcon      *mini_doc;              // Mini document icon
-    FXIcon      *big_exec;              // Big executable icon
-    FXIcon      *mini_exec;             // Mini executable icon
+    FXIcon      *big_folder;            
+    FXIcon      *mini_folder;           
+    FXIcon      *big_doc;               
+    FXIcon      *mini_doc;              
+    FXIcon      *big_exec;              
+    FXIcon      *mini_exec;             
 	FXIcon  	*mini_folderopen;
 	FXIcon  	*mini_folderup;
 	FXIcon  	*mini_lockfolder;
@@ -136,6 +136,7 @@ protected:
 	FXIcon  	*mini_sock;
 	FXIcon  	*mini_pipe;
 	FXIcon  	*mini_link;
+	FXIcon  	*mini_brokenlink;
 	FXIcon  	*big_folderopen;
 	FXIcon  	*big_folderup;
 	FXIcon  	*big_lockfolder;
@@ -146,6 +147,7 @@ protected:
 	FXIcon  	*big_harddisk;
 	FXIcon  	*mini_harddisk;
 	FXIcon  	*big_link;
+	FXIcon  	*big_brokenlink;
     FXIcon  	*big_nfs;
     FXIcon  	*mini_nfs;
     FXIcon  	*big_floppy;
