@@ -1,4 +1,5 @@
 #include "config.h"
+#include "config.h"
 #include "i18n.h"
 
 #include <stdio.h>
@@ -28,11 +29,7 @@
 
 // Global Variables
 extern FXMainWindow *mainWindow;
-extern FXString editor;
-extern FXString viewer;
 extern FXString clipboard;
-extern FXbool use_trashcan;
-extern FXbool confirm_del;
 extern char OpenHistory[OPEN_WITH_HIST_SIZE][100];
 extern int OpenNum;
 #if defined(linux)
@@ -43,7 +40,6 @@ extern FXStringDict* mtdevices;
 FXuint clptype=0;
 
 
-
 // Map
 FXDEFMAP(FilePanel) FilePanelMap[]={
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_DIRECTORY_UP,FilePanel::onCmdDirectoryUp),
@@ -120,7 +116,7 @@ FXIMPLEMENT(FilePanel,FXVerticalFrame,FilePanelMap,ARRAYNUMBER(FilePanelMap))
 
 // Construct File Panel
 FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_size, FXuint type_size, 
-             FXuint modd_size, FXuint user_size, FXuint grou_size, FXuint attr_size,
+             FXuint modd_size, FXuint user_size, FXuint grou_size, FXuint attr_size, FXColor listbackcolor, FXColor listforecolor,
 			 FXuint opts,FXint x,FXint y,FXint w,FXint h):
              FXVerticalFrame(p,opts,x,y,w,h,0,0,0,0)
 {
@@ -160,15 +156,18 @@ FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_si
     label->setTarget(this);
     label->setSelector(FXSEL(0,FilePanel::ID_LABEL));
 
-    list=new FileList(cont,this,ID_FILE_PANEL,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_BIG_ICONS);
-    list->setHeaderSize(0,name_size);
+    list=new FileList(cont,this,ID_FILE_PANEL,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE);
+	
+	list->setHeaderSize(0,name_size);
     list->setHeaderSize(1,size_size);
     list->setHeaderSize(2,type_size);
     list->setHeaderSize(3,modd_size);
     list->setHeaderSize(4,user_size);
     list->setHeaderSize(5,grou_size);
-    list->setHeaderSize(6,attr_size);  
-
+    list->setHeaderSize(6,attr_size);  	
+	list->setTextColor(listforecolor);
+	list->setBackColor(listbackcolor);
+	
 	statusbar=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
     new FXToggleButton(statusbar,_("\tShow hidden files (Ctrl-F6)"),_("\tHide hidden files (Ctrl-F6)"),showhiddenicon,hidehiddenicon,this->list,
 	                   FileList::ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
@@ -296,7 +295,7 @@ long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
 {
     FXString buf, filename, filepath;
 
-    int item= (int) ptr;
+    long item= (long) ptr;
     if(item > -1)
     {
 		// File name and path
@@ -454,7 +453,10 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 	FXString dir=current->list->getDirectory();
     chdir(dir.text());
 
-    // If we don't have permission to write to the parent directory
+    FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
+	FXbool use_trashcan=getApp()->reg().readUnsignedEntry("OPTIONS","use_trashcan",TRUE);
+	
+	// If we don't have permission to write to the parent directory
     if(!::isWritable(dir))
     {
         MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s: Permission denied"),dir.text());
@@ -473,7 +475,7 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 			
 		FXString filepath=((XFileExplorer*) mainWindow)->dirpanel->list->getItemPathname((TreeItem*)item);
 
-    	if(confirm_del)
+		if(confirm_del)
     	{
         	FXPNGIcon icon(getApp(),delete_big);
 			FXString message=_("Delete folder ") + filepath + " ?";
@@ -751,7 +753,9 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 // Edit file
 long FilePanel::onCmdEdit(FXObject*,FXSelector s,void*)
 {
-    current->list->setFocus();
+    FXString editor=getApp()->reg().readStringEntry("PROGS","editor","nedit ");
+    FXString viewer=getApp()->reg().readStringEntry("PROGS","viewer","xfv ");
+	current->list->setFocus();
     chdir(current->list->getDirectory().text());
 	FXString filename, filepath;
 
@@ -890,8 +894,12 @@ long FilePanel::onCmdNewDir(FXObject*,FXSelector,void*)
 		dirname=dirpath+dialog->getText();
         if(dirname!=dirpath)
         {
-			// Create the new dir
-			FXint ret=::mkdir(dirname.text(),0755);
+			// Create the new dir according to the current umask
+			int mask;
+			mask=umask(0);
+			umask(mask);
+			// note that the umask value is in decimal (511 means octal 0777)
+			FXint ret=::mkdir(dirname.text(),511 & ~mask);
 			if (ret==-1)
 			{
          		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
@@ -923,7 +931,8 @@ long FilePanel::onCmdNewFile(FXObject*,FXSelector,void*)
     if(dialog->execute(PLACEMENT_CURSOR))
     {
 		filename=filepath+dialog->getText();
-        if(filename!=filepath)
+		FILE *file;
+		if(filename!=filepath)
         {
 			// Test some error conditions
 			if (::exists(filename))
@@ -932,13 +941,17 @@ long FilePanel::onCmdNewFile(FXObject*,FXSelector,void*)
         		return 0;
 			}
 			// Create the new file
-			FILE *file=fopen(filename.text(),"w+");
-			if (file==NULL)
+			if (!(file=fopen(filename.text(),"w+"))  ||  fclose(file) )
 			{
          		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
     			return 0;
 			}
-			fclose(file);								
+			// Change the file permissions according to the current umask
+			int mask;
+			mask=umask(0);
+			umask(mask);
+			if (chmod(filename.text(), 438 & ~mask) != 0)
+         		MessageBox::error(this,MBOX_OK,_("Error"), _("Setting permissions: %s"),strerror(errno));
 		}							
     }
     delete dialog;
@@ -974,7 +987,7 @@ long FilePanel::onCmdPaste(FXObject*,FXSelector sel,void*)
 
 // Clipboard
 long FilePanel::onCmdClp(FXObject*,FXSelector sel,void*)
-{
+{	
     FXString name,curdir;
 
 	// Empty clipboard
@@ -1021,6 +1034,7 @@ long FilePanel::onCmdClp(FXObject*,FXSelector sel,void*)
         	}
     	clipboard=FXStringVal(num)+"\n"+clipboard;
 	}
+		
     return 1;
 }
 
@@ -1311,8 +1325,8 @@ long FilePanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
         new FXMenuRadio(&menu,_("S&mall icons"),current->list,FXIconList::ID_SHOW_MINI_ICONS);
         new FXMenuRadio(&menu,_("F&ull file list"),current->list,FXIconList::ID_SHOW_DETAILS);
         new FXMenuSeparator(&menu);
-        new FXMenuRadio(&menu,_("&Rows"),current->list,FXIconList::ID_ARRANGE_BY_ROWS);
-        new FXMenuRadio(&menu,_("&Columns"),current->list,FXIconList::ID_ARRANGE_BY_COLUMNS);
+        new FXMenuRadio(&menu,_("&Rows"),current->list,FileList::ID_ARRANGE_BY_ROWS);
+        new FXMenuRadio(&menu,_("&Columns"),current->list,FileList::ID_ARRANGE_BY_COLUMNS);
         new FXMenuSeparator(&menu);
         new FXMenuRadio(&menu,_("&Name"),current->list,FileList::ID_SORT_BY_NAME);
         new FXMenuRadio(&menu,_("&Type"),current->list,FileList::ID_SORT_BY_TYPE);
@@ -1436,16 +1450,30 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 	
 	chdir(current->list->getDirectory().text());
 
-    if(current->list->getNumSelectedItems()==0)
-        return 0;
-
   	// Eventually deselect the '..' directory
 	if (current->list->isItemSelected(0))
 		current->list->deselectItem(0);
 
-    HistInputDialog* dialog;
-    FXString archpath=current->list->getDirectory();
+	// Return if nothing is selected
+	if(current->list->getNumSelectedItems()==0)
+		return 0;
 
+	// If only one item is selected and if it is a directory
+	// use its name as a starting guess for the archive name
+	if (current->list->getNumSelectedItems()==1)
+	{
+		for (int u= 0; u< current->list->getNumItems(); u++)
+			if (current->list->isItemSelected(u))
+			{
+				name=list->getItemFilename(u);
+				break;
+			}
+		if (::isDirectory(name))
+			archive=name;
+	}
+	
+	HistInputDialog* dialog;
+    FXString archpath=current->list->getDirectory();	
     dialog=new HistInputDialog(this,archive,
 	      _("Create new archive: (e.g. archive.tar.gz)\n=>Supported formats : tar, tgz, tbz2, taz, gz, bz2, Z, zip, rar, lzh"),
 		  _("Add To Archive"));
@@ -1456,7 +1484,7 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
     if(dialog->execute())
     {
         // Get string and preserve escape characters
-		archive=archpath+PATHSEPSTRING+"\""+dialog->getText()+"\"";
+		archive="\""+archpath+PATHSEPSTRING+dialog->getText()+"\"";
 
         // Get extensions of the archive name
         ext1=dialog->getText().rafter('.',1);
@@ -1999,7 +2027,7 @@ long FilePanel::onUpdMount(FXObject* o,FXSelector sel,void*)
 		}
 	}		
 
-	if(fsdevices->find(dir.text()) && !mtdevices->find(dir.text()) && !current->list->isItemSelected(0))
+	if(fsdevices->find(dir.text()) && !mtdevices->find(dir.text()) && current->list->getNumItems() && !current->list->isItemSelected(0))
         o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
     else
         o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
@@ -2028,7 +2056,7 @@ long FilePanel::onUpdUnmount(FXObject* o,FXSelector sel,void*)
 		}
 	}		
 
-	if(fsdevices->find(dir.text()) && mtdevices->find(dir.text()) && !current->list->isItemSelected(0))
+	if(fsdevices->find(dir.text()) && mtdevices->find(dir.text()) && current->list->getNumItems() && !current->list->isItemSelected(0))
         o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
     else
         o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
@@ -2162,7 +2190,7 @@ long FilePanel::onUpdStatus(FXObject* sender,FXSelector,void*)
             grp=file;
             perm=p+1;
         }
-        if(strstr(ext.text(),_("Link")) || strstr(ext.text(),_("Broken link")))
+		if(strstr(ext.text(),_("Broken link")))
         {
             FXint nread;
 
@@ -2170,7 +2198,18 @@ long FilePanel::onUpdStatus(FXObject* sender,FXSelector,void*)
             if(nread>0)
             {
                 buf[nread]='\0';
-                status->setText(name+" -> "+buf);
+                status->setText(name+" -> "+buf+_(" (broken link)"));
+            }
+        }
+		else if(strstr(ext.text(),_("Link")))
+        {
+            FXint nread;
+
+            nread=readlink((path+PATHSEPSTRING+name).text(),buf,sizeof(buf)-1);
+            if(nread>0)
+            {
+                buf[nread]='\0';
+                status->setText(name+ " -> "+buf);
             }
         }
         else
