@@ -13,10 +13,9 @@
 #include "MessageBox.h"
 
 
-
 FXbool Theme::operator != (const Theme& t)
 {
-    for(int i=0;i<6;i++)
+    for(int i=0;i<8;i++)
         if(color[i] != t.color[i])
             return TRUE;
     return FALSE;
@@ -25,17 +24,6 @@ FXbool Theme::operator != (const Theme& t)
 // Main window
 extern FXMainWindow *mainWindow;
 
-// Global Flags
-FXbool confirm_quit;
-FXbool confirm_del;
-FXbool confirm_overwrite;
-FXbool ask_before_copy;
-FXbool warn_if_root;
-FXbool use_trashcan;
-#if defined(linux)
-FXbool mount_warn;
-FXbool mount_messages;
-#endif
 
 // Map
 FXDEFMAP(PreferencesBox) PreferencesMap[]={
@@ -54,7 +42,7 @@ FXDEFMAP(PreferencesBox) PreferencesMap[]={
 FXIMPLEMENT(PreferencesBox,FXDialogBox,PreferencesMap,ARRAYNUMBER(PreferencesMap))
 
 // Construct window for one file
-PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"), DECOR_TITLE|DECOR_BORDER)
+PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor listforecolor): FXDialogBox(win,_("Preferences"), DECOR_TITLE|DECOR_BORDER)
 {
     currTheme.name = _("Current Theme");
     currTheme.color[0] = getApp()->getBaseColor();
@@ -63,17 +51,19 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     currTheme.color[3] = getApp()->getForeColor();
     currTheme.color[4] = getApp()->getSelbackColor();
     currTheme.color[5] = getApp()->getSelforeColor();
+    currTheme.color[6] = listbackcolor;
+    currTheme.color[7] = listforecolor;
 
     Themes[0] = currTheme;
-    Themes[1] = Theme("GNOME",FXRGB(214,215,214),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255));
-    Themes[2] = Theme("KDE",FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,131),FXRGB(255,255,255));
-    Themes[3] = Theme("CDE",FXRGB(156,153,156),FXRGB(0,0,0),FXRGB(131,129,131),FXRGB(255,255,255),FXRGB(49,97,131),FXRGB(255,255,255));
-    Themes[4] = Theme("Digital CDE",FXRGB(74,121,131),FXRGB(0,0,0),FXRGB(49,76,74),FXRGB(255,255,255),FXRGB(65,80,90),FXRGB(255,255,255));
-    Themes[5] = Theme("Sea Sky",FXRGB(165,178,198),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(49,101,156),FXRGB(255,255,255));
-    Themes[6] = Theme("Blue Slate",FXRGB(156,186,205),FXRGB(0,0,0),FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(82,129,148),FXRGB(255,255,255));
-    Themes[7] = Theme("iMac",FXRGB(205,206,205),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255));
-    Themes[8] = Theme("BeOS",FXRGB(222,218,222),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(172,170,172),FXRGB(255,255,255));
-	Themes[9] = Theme("Windows 95",FXRGB(192,192,192),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255));
+    Themes[1] = Theme("GNOME2",FXRGB(220,218,213),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(75,105,131),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0));
+    Themes[2] = Theme("KDE3",FXRGB(238,238,230),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(255,222,118),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0));
+    Themes[3] = Theme("CDE",FXRGB(156,153,156),FXRGB(0,0,0),FXRGB(131,129,131),FXRGB(255,255,255),FXRGB(49,97,131),FXRGB(255,255,255),FXRGB(131,129,131),FXRGB(255,255,255));
+    Themes[4] = Theme("Digital CDE",FXRGB(74,121,131),FXRGB(0,0,0),FXRGB(49,76,74),FXRGB(255,255,255),FXRGB(65,80,90),FXRGB(255,255,255),FXRGB(49,76,74),FXRGB(255,255,255));
+    Themes[5] = Theme("Sea Sky",FXRGB(165,178,198),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(49,101,156),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0));
+    Themes[6] = Theme("Blue Slate",FXRGB(156,186,205),FXRGB(0,0,0),FXRGB(197,194,197),FXRGB(0,0,0),FXRGB(82,129,148),FXRGB(255,255,255),FXRGB(197,194,197),FXRGB(0,0,0));
+    Themes[7] = Theme("iMac",FXRGB(205,206,205),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0));
+    Themes[8] = Theme("BeOS",FXRGB(222,218,222),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(172,170,172),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0));
+	Themes[9] = Theme("Windows 95",FXRGB(192,192,192),FXRGB(0,0,0),FXRGB(255,255,255),FXRGB(0,0,0),FXRGB(0,0,128),FXRGB(255,255,255),FXRGB(255,255,255),FXRGB(0,0,0));
 
 
     // Buttons
@@ -131,25 +121,36 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     del=new FXCheckButton(group,_("Confirm delete"));
     overwrite=new FXCheckButton(group,_("Confirm overwrite"));
     ask=new FXCheckButton(group,_("Always ask before file operation"));
-    quit=new FXCheckButton(group,_("Confirm quit"));
+    autosave=new FXCheckButton(group,_("Auto save layout"));
+	quit=new FXCheckButton(group,_("Confirm quit"));
     group=new FXGroupBox(options,_("Warnings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 #if defined(linux)
     mount=new FXCheckButton (group,_("Warn when mount points are not responding"));
 	show_mount=new FXCheckButton(group, _("Display mount/umount success messages"));
 #endif
-    root_warn=new FXCheckButton (group,_("Warn if running as root"));
+    root_warning=new FXCheckButton (group,_("Warn if running as root"));
 
-    if(getuid())//running as a user?
-        root_warn->disable();
+    FXbool root_warn=getApp()->reg().readUnsignedEntry("OPTIONS","root_warn",TRUE);
+	if(getuid())//running as a user?
+        root_warning->disable();
     else
-        root_warn->setCheck(warn_if_root);
+        root_warning->setCheck(root_warn);
 
-    trashcan->setCheck(use_trashcan);
+    FXbool use_trashcan=getApp()->reg().readUnsignedEntry("OPTIONS","use_trashcan",TRUE);
+	trashcan->setCheck(use_trashcan);
+    FXbool auto_save_layout=getApp()->reg().readUnsignedEntry("OPTIONS","auto_save_layout",TRUE);
+	autosave->setCheck(auto_save_layout);
+	FXbool confirm_quit=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_quit",TRUE);
 	quit->setCheck(confirm_quit);
-    del->setCheck(confirm_del);
-    overwrite->setCheck(confirm_overwrite);
-    ask->setCheck(ask_before_copy);
+    FXbool confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
+	del->setCheck(confirm_del);
+    FXbool confirm_overwrite=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_overwrite",TRUE);
+	overwrite->setCheck(confirm_overwrite);
+    FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
+	ask->setCheck(ask_before_copy);
 #if defined(linux)
+	FXbool mount_warn=getApp()->reg().readUnsignedEntry("OPTIONS","mount_warn",TRUE);
+	FXbool mount_messages=getApp()->reg().readUnsignedEntry("OPTIONS","mount_messages",TRUE);
 	mount->setCheck(mount_warn);
 	show_mount->setCheck(mount_messages);
 #endif
@@ -161,7 +162,7 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     FXHorizontalFrame *col=new FXHorizontalFrame(colors,LAYOUT_FILL_X);
 
     colorsBox = new FXComboBox(col,8,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT);
-  	colorsBox->setNumVisible(5);
+  	colorsBox->setNumVisible(8);
     FXPacker *pack = new FXPacker(col,LAYOUT_SIDE_LEFT|FRAME_SUNKEN|LAYOUT_FILL_Y);
     cwell = new FXButton(pack,"",NULL,this,ID_COLOR,LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y,0,0, 30);
 
@@ -171,6 +172,8 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     colorsBox->appendItem(_("Foreground color"));
     colorsBox->appendItem(_("Selection background color"));
     colorsBox->appendItem(_("Selection foreground color"));
+    colorsBox->appendItem(_("File list background color"));
+    colorsBox->appendItem(_("File list foreground color"));
     colorsBox->setCurrentItem(0);
 
     FXGroupBox *themes=new FXGroupBox(visual,_("Color Theme"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);//|LAYOUT_FILL_Y);
@@ -346,40 +349,31 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
     if(oldxterm != xterm->getText())
         getApp()->reg().writeStringEntry("PROGS","xterm",xterm->getText().text());
 
-    confirm_quit=quit->getCheck();
-	use_trashcan=trashcan->getCheck();
-    confirm_del=del->getCheck();
-    confirm_overwrite=overwrite->getCheck();
-    ask_before_copy=ask->getCheck();
-    warn_if_root=root_warn->getCheck();
-#if defined(linux)
-	mount_warn=mount->getCheck();
-	mount_messages=show_mount->getCheck();
-#endif
-	
-    getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","auto_save_layout",autosave->getCheck());
+	getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","use_trashcan",trashcan->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete",del->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_overwrite",overwrite->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","ask_before_copy",ask->getCheck());
-    getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warn->getCheck());
+    getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warning->getCheck());
 #if defined(linux)
     getApp()->reg().writeUnsignedEntry("OPTIONS","mount_warn",mount->getCheck());
 	getApp()->reg().writeUnsignedEntry("OPTIONS","mount_messages",show_mount->getCheck());
 #endif
-
     if(currTheme != Themes[0])
     {
-        getApp()->reg().writeColorEntry("SETTINGS","basecolor",currTheme.color[0]);
+		getApp()->reg().writeColorEntry("SETTINGS","basecolor",currTheme.color[0]);
         getApp()->reg().writeColorEntry("SETTINGS","bordercolor",currTheme.color[1]);
         getApp()->reg().writeColorEntry("SETTINGS","backcolor",currTheme.color[2]);
         getApp()->reg().writeColorEntry("SETTINGS","forecolor",currTheme.color[3]);
         getApp()->reg().writeColorEntry("SETTINGS","selbackcolor",currTheme.color[4]);
         getApp()->reg().writeColorEntry("SETTINGS","selforecolor",currTheme.color[5]);
+		getApp()->reg().writeColorEntry("SETTINGS","listbackcolor",currTheme.color[6]);
+		getApp()->reg().writeColorEntry("SETTINGS","listforecolor",currTheme.color[7]);
+
         if(MBOX_CLICKED_CANCEL!=MessageBox::question(this,MBOX_OK_CANCEL,_("Restart"),_("Colors will be changed after restart.\nRestart X File Explorer now?")))
             mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RESTART),NULL);
     }
-    mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RELOAD_PREFS),NULL);
     FXDialogBox::onCmdAccept(o,s,p);
     return 1;
 }
