@@ -10,12 +10,13 @@
 struct Theme
 {
     char *name;
-    FXColor color[6];
+    FXColor color[8];
     Theme()
     {
         name = "";
     };
-    Theme(const char *n,FXColor base=0,FXColor bdr=0,FXColor bg=0,FXColor fg=0,FXColor selbg=0,FXColor selfg=0)
+    Theme(const char *n,FXColor base=0,FXColor bdr=0,FXColor bg=0,FXColor fg=0,
+	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0)
     {
         name = strdup(n);
         color[0] = base;
@@ -24,6 +25,8 @@ struct Theme
         color[3] = fg;
         color[4] = selbg;
         color[5] = selfg;
+		color[6] = listbg;
+		color[7] = listfg;
     };
     FXbool operator != (const Theme&);
 };
@@ -50,13 +53,14 @@ private:
     FXString    oldxterm;
     FXString    oldnormalfont;
     FXString    oldtextfont;
+    FXCheckButton  *autosave;
     FXCheckButton  *quit;
     FXCheckButton  *trashcan;
     FXCheckButton  *del;
     FXCheckButton  *overwrite;
     FXCheckButton  *ask;
     FXCheckButton  *bg;
-    FXCheckButton  *root_warn;
+    FXCheckButton  *root_warning;
     FXCheckButton  *mount;
 	FXCheckButton  *show_mount;
     Theme          Themes[THEMES_NUM];
@@ -76,7 +80,7 @@ public:
     };
 
 public:
-    PreferencesBox(FXWindow *win);
+    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0));
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
     long onCmdColor (FXObject*,FXSelector,void*);
