@@ -209,10 +209,10 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     FXString editlbl=_("Edit:");
 
 	extension=file.rafter('.',1);
-	if(extension=="gz" || extension=="GZ"  || extension=="tgz" || extension=="TGZ" ||
-		extension=="tar"|| extension=="TAR"|| extension=="bz2" || extension=="BZ2" ||
-		extension=="tbz2" || extension=="TBZ2" || extension=="zip" || extension=="ZIP" ||
-		extension=="Z")
+	if (comparecase(extension,"gz") || comparecase(extension,"tgz") ||
+		comparecase(extension,"tar") || comparecase(extension,"bz2") ||
+		comparecase(extension,"tbz2") || comparecase(extension,"zip") ||
+		comparecase(extension,"Z"))
 	{
 		is_ar = TRUE; // archive
 		viewlbl = _("Extract:");
@@ -353,7 +353,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
             type+=_("Folder");
     		getApp()->beginWaitCursor();
 			strlcpy(buf,dupath.text(),dupath.length()+1);
-			dirsize=dirpath(buf);
+			dirsize=pathsize(buf);
 			snprintf(size,sizeof(size)-1,"%llu",dirsize);
     		getApp()->endWaitCursor();
 		}
@@ -620,7 +620,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n,FXString path):
 			// Recursive size
 			FXString dupath=FXFile::absolute(path,files[i]);
 			strlcpy(buf,dupath.text(),dupath.length()+1);
-			dirsize=dirpath(buf);
+			dirsize=pathsize(buf);
 			totalsize+=dirsize;
 			nbdirs++;
 		}
