@@ -25,6 +25,7 @@ private:
 	FXRadioButton*	add;
 	FXint			cmd;		  
     FXCheckButton*	rec;
+    FXCheckButton*	own;
     FXCheckButton*	dironly;
     FXComboBox*		user;
     FXComboBox*		userbis;
@@ -95,15 +96,16 @@ public:
     };
 
 public:
+    virtual void create();
     PropertiesBox(FXWindow *win,FXString file,FXString path);
-    PropertiesBox(FXWindow *win,FXString *files,int num);
+    PropertiesBox(FXWindow *win,FXString *files,int num,FXString path);
     long onCmdAcceptSingle(FXObject*,FXSelector,void*);
     long onCmdAcceptMult(FXObject*,FXSelector,void*);
     long onCmdCheck(FXObject*,FXSelector,void*);
     long onCmdCommand(FXObject*,FXSelector,void*);
     long onCmdBrowseIcon(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
-	long onUpdDironly(FXObject*,FXSelector,void*);
+	long onUpdPerm(FXObject*,FXSelector,void*);
     long onCmdKeyPress(FXObject*,FXSelector,void*);
 };
 
