@@ -39,8 +39,6 @@
 
 
 // Global variables
-FXString editor;
-FXString viewer;
 FXString clipboard="";
 char OpenHistory[OPEN_WITH_HIST_SIZE][100];
 int OpenNum;
@@ -48,16 +46,10 @@ int OpenNum;
 // External global variables
 extern FXMainWindow *mainWindow;
 extern char** args;
+
+// Global options
 extern FXString startdir;
-extern FXbool confirm_quit;
-extern FXbool warn_if_root;
-extern FXbool use_trashcan;
-extern FXbool confirm_del;
-extern FXbool confirm_overwrite;
-extern FXbool ask_before_copy;
 #if defined(linux)
-extern FXbool mount_warn;
-extern FXbool mount_messages;
 extern FXStringDict* fsdevices;
 extern FXStringDict* updevices;
 #endif
@@ -97,6 +89,7 @@ void FXSplitter::moveHSplit(FXint pos)
         if((hints&LAYOUT_FILL_X)&&(hints&LAYOUT_FIX_WIDTH))
             smin+=window->getDefaultWidth();
     }
+
 	// !!! Hack to limit the width to a minimum value !!!
 	smax=smax-MIN_PANEL_WIDTH;
     split=pos;
@@ -124,21 +117,24 @@ FXDEFMAP(XFileExplorer) XFileExplorerMap[]={
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_REFRESH,XFileExplorer::onCmdRefresh),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_EMPTY_TRASHCAN,XFileExplorer::onCmdEmptyTrashcan),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_XTERM,XFileExplorer::onCmdXTerm),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_AUTO_SAVE,XFileExplorer::onCmdAutoSave),
 									 FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_CLEAR_LOCATION,XFileExplorer::onCmdClearLocation),
 									 FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_GOTO_LOCATION,XFileExplorer::onCmdGotoLocation),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_PREFS,XFileExplorer::onCmdPrefs),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RELOAD_PREFS,XFileExplorer::onCmdReloadPrefs),
+                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_ONE_PANEL,XFileExplorer::onCmdShowPanels),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TWO_PANELS,XFileExplorer::onCmdShowPanels),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TREE_PANEL,XFileExplorer::onCmdShowPanels),
-                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RESTART,XFileExplorer::onCmdRestart),
+                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,XFileExplorer::onCmdShowPanels),
+			                         FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_RESTART,XFileExplorer::onCmdRestart),
+                                     FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_NEW_WIN,XFileExplorer::onCmdNewWindow),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_BOOKMARK,XFileExplorer::onCmdBookmark),
                                      FXMAPFUNC(SEL_COMMAND,XFileExplorer::ID_ADD_BOOKMARK,XFileExplorer::onCmdBookmark),
             						 FXMAPFUNC(SEL_KEYPRESS,0,XFileExplorer::onKeyPress),
                                      FXMAPFUNC(SEL_CLOSE,0,XFileExplorer::onQuit),
                                      FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_TOGGLE_STATUS,XFileExplorer::onUpdToggleStatus),
+                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_ONE_PANEL,XFileExplorer::onUpdShowPanels),
                                      FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TWO_PANELS,XFileExplorer::onUpdShowPanels),
                                      FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TREE_PANEL,XFileExplorer::onUpdShowPanels),
+                                     FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,XFileExplorer::onUpdShowPanels),
 									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_GOTO_LOCATION,XFileExplorer::onUpdFileLocation),
 									 FXMAPFUNC(SEL_UPDATE,XFileExplorer::ID_EMPTY_TRASHCAN,XFileExplorer::onUpdEmptyTrashcan),
                                  };
@@ -168,9 +164,11 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
 	FXIcon *hidehiddenicon=new FXPNGIcon(app,hidehidden);
 	FXIcon *showthumbicon=new FXPNGIcon(app,showthumb);
 	FXIcon *hidethumbicon=new FXPNGIcon(app,hidethumb);
+	FXIcon *onepanelicon=new FXPNGIcon(app,onepanel);
 	FXIcon *twopanelsicon=new FXPNGIcon(app,twopanels);
-	FXIcon *xtermicon=new FXPNGIcon(app,shell);
 	FXIcon *treepanelicon=new FXPNGIcon(app,treeonepanel);
+	FXIcon *treetwopanelsicon=new FXPNGIcon(app,treetwopanels);
+	FXIcon *xtermicon=new FXPNGIcon(app,shell);
 	FXIcon *setbookicon=new FXPNGIcon(app,setbook);
 	FXIcon *clrbookicon=new FXPNGIcon(app,clrbook);
 	FXIcon *runicon=new FXPNGIcon(app,run);
@@ -199,6 +197,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
   	FXIcon *entericon=new FXPNGIcon(app,enter);
 	FXIcon *filtericon=new FXPNGIcon(app,filter);
 	FXIcon *openicon=new FXPNGIcon(app,fileopen);
+    FXIcon *filemanagericon= new FXPNGIcon(app,miniFileManager);
 
 	// Site where to dock
 	FXDockSite *docksite=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
@@ -222,8 +221,12 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
   	FXHorizontalFrame * splitterbox=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
 	FXSplitter* mainsplit=new FXSplitter(splitterbox,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING);
 
-    // Directory panel on the left (with minimum size)
-    dirpanel=new DirPanel(mainsplit,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH,0,0,MIN_PANEL_WIDTH,0);
+    // File list background and foreground colors
+	listbackcolor=getApp()->reg().readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
+	listforecolor=getApp()->reg().readColorEntry("SETTINGS","listforecolor",FXRGB(0,0,0));
+		
+	// Directory panel on the left (with minimum size)
+    dirpanel=new DirPanel(mainsplit,listbackcolor,listforecolor,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH,0,0,MIN_PANEL_WIDTH,0);
 
 	// Sub splitter
     FXSplitter* subsplit=new FXSplitter(mainsplit,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING);
@@ -237,6 +240,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
                      getApp()->reg().readUnsignedEntry("LEFT PANEL","user_size",50),
                      getApp()->reg().readUnsignedEntry("LEFT PANEL","grou_size",50),
                      getApp()->reg().readUnsignedEntry("LEFT PANEL","attr_size",100),
+					 listbackcolor,listforecolor,
 					 LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH,0,0,MIN_PANEL_WIDTH,0);
     rpanel=new FilePanel("RIGHT PANEL",subsplit,
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","name_size",200),
@@ -246,6 +250,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","user_size",50),
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","grou_size",50),
                      getApp()->reg().readUnsignedEntry("RIGHT PANEL","attr_size",100),
+					 listbackcolor,listforecolor,
 					 LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH,0,0,MIN_PANEL_WIDTH,0);
     lpanel->Next(rpanel);
     rpanel->Next(lpanel);
@@ -370,11 +375,25 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
 
 	toolbarSeparator(toolbar);
 
+	// Show one panel
+   	btn = new FXButton(toolbar,_("\tShow one panel (Ctrl-F1)"),onepanelicon,this,XFileExplorer::ID_SHOW_ONE_PANEL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
+    hotkey = (0004<<16) | KEY_F1;
+   	btn->addHotKey(hotkey);
+
 	// Show tree and panel
-   	new FXButton(toolbar,_("\tShow tree and panel (Ctrl-F1)"),treepanelicon,this,XFileExplorer::ID_SHOW_TREE_PANEL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
+   	new FXButton(toolbar,_("\tShow tree and panel (Ctrl-F2)"),treepanelicon,this,XFileExplorer::ID_SHOW_TREE_PANEL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
+    hotkey = (0004<<16) | KEY_F2;
+   	btn->addHotKey(hotkey);
 
 	// Show two panels
-   	new FXButton(toolbar,_("\tShow two panels (Ctrl-F2)"),twopanelsicon,this,XFileExplorer::ID_SHOW_TWO_PANELS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
+   	new FXButton(toolbar,_("\tShow two panels (Ctrl-F3)"),twopanelsicon,this,XFileExplorer::ID_SHOW_TWO_PANELS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
+    hotkey = (0004<<16) | KEY_F3;
+   	btn->addHotKey(hotkey);
+
+	// Show tree and two panels
+   	btn = new FXButton(toolbar,_("\tShow tree and two panels (Ctrl-F4)"),treetwopanelsicon,this,XFileExplorer::ID_SHOW_TREE_TWO_PANELS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
+    hotkey = (0004<<16) | KEY_F4;
+   	btn->addHotKey(hotkey);
 
 	// Show or hide hidden files (button not shown : just to add the shortcut)   
     tgbtn=new FXToggleButton(toolbar,_("\tHide hidden files (Ctrl-F6)"),_("\tShow hidden files (Ctrl-F6)"),hidehiddenicon,showhiddenicon,lpanel->current,FilePanel::ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT|ICON_BEFORE_TEXT);
@@ -416,6 +435,7 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
 
     // File menu
     FXMenuPane* commenu=new FXMenuPane(this);
+    new FXMenuCommand(commenu,_("New &window\tF3"),filemanagericon,this,XFileExplorer::ID_NEW_WIN);
     new FXMenuCommand(commenu,_("New &file...\tF2"),minidocicon,lpanel->current,FilePanel::ID_NEW_FILE);
     new FXMenuCommand(commenu,_("New fo&lder...\tF7"),newfoldericon,lpanel->current,FilePanel::ID_NEW_DIR);
     new FXMenuCommand(commenu,_("&Execute command...\tCtrl-E"),runicon,this,ID_RUN);
@@ -488,11 +508,12 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
 	new FXMenuCheck(viewmenu,_("&Location bar"),locationbar,FXWindow::ID_TOGGLESHOWN);
     new FXMenuCheck(viewmenu,_("&Status bar"),this,XFileExplorer::ID_TOGGLE_STATUS);
     new FXMenuSeparator(viewmenu);
-    new FXMenuRadio(viewmenu,_("T&ree and panel\tCtrl-F1"),this,XFileExplorer::ID_SHOW_TREE_PANEL);
-    new FXMenuRadio(viewmenu,_("Two &panels\tCtrl-F2"),this,XFileExplorer::ID_SHOW_TWO_PANELS);
+    new FXMenuRadio(viewmenu,_("&One panel\tCtrl-F1"),this,XFileExplorer::ID_SHOW_ONE_PANEL);
+    new FXMenuRadio(viewmenu,_("T&ree and panel\tCtrl-F2"),this,XFileExplorer::ID_SHOW_TREE_PANEL);
+    new FXMenuRadio(viewmenu,_("Two &panels\tCtrl-F3"),this,XFileExplorer::ID_SHOW_TWO_PANELS);
+    new FXMenuRadio(viewmenu,_("T&ree and two panels\tCtrl-F4"),this,XFileExplorer::ID_SHOW_TREE_TWO_PANELS);
     new FXMenuSeparator(viewmenu);
     new FXMenuCheck(viewmenu,_("&Hidden folders\tCtrl-F5"),dirpanel,DirPanel::ID_TOGGLE_HIDDEN);
-    FXMenuCheck* autosave=new FXMenuCheck(viewmenu,_("&Auto save layout"),this,XFileExplorer::ID_AUTO_SAVE);
     new FXMenuTitle(menubar,_("&View"),NULL,viewmenu);
 
     // Left View Menu Pane
@@ -505,8 +526,8 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuRadio(leftviewmenu,_("&Small icons"),lpanel->list,FXIconList::ID_SHOW_MINI_ICONS);
     new FXMenuRadio(leftviewmenu,_("F&ull file list"),lpanel->list,FXIconList::ID_SHOW_DETAILS);
     new FXMenuSeparator(leftviewmenu);
-    new FXMenuRadio(leftviewmenu,_("&Rows"),lpanel->list,FXIconList::ID_ARRANGE_BY_ROWS);
-    new FXMenuRadio(leftviewmenu,_("&Columns"),lpanel->list,FXIconList::ID_ARRANGE_BY_COLUMNS);
+    new FXMenuRadio(leftviewmenu,_("&Rows"),lpanel->list,FileList::ID_ARRANGE_BY_ROWS);
+    new FXMenuRadio(leftviewmenu,_("&Columns"),lpanel->list,FileList::ID_ARRANGE_BY_COLUMNS);
     new FXMenuSeparator(leftviewmenu);
     new FXMenuRadio(leftviewmenu,_("&Name"),lpanel->list,FileList::ID_SORT_BY_NAME);
     new FXMenuRadio(leftviewmenu,_("Si&ze"),lpanel->list,FileList::ID_SORT_BY_SIZE);
@@ -525,8 +546,8 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuRadio(rightviewmenu,_("&Small icons"),rpanel->list,FXIconList::ID_SHOW_MINI_ICONS);
     new FXMenuRadio(rightviewmenu,_("F&ull file list"),rpanel->list,FXIconList::ID_SHOW_DETAILS);
     new FXMenuSeparator(rightviewmenu);
-    new FXMenuRadio(rightviewmenu,_("&Rows"),rpanel->list,FXIconList::ID_ARRANGE_BY_ROWS);
-    new FXMenuRadio(rightviewmenu,_("&Columns"),rpanel->list,FXIconList::ID_ARRANGE_BY_COLUMNS);
+    new FXMenuRadio(rightviewmenu,_("&Rows"),rpanel->list,FileList::ID_ARRANGE_BY_ROWS);
+    new FXMenuRadio(rightviewmenu,_("&Columns"),rpanel->list,FileList::ID_ARRANGE_BY_COLUMNS);
     new FXMenuSeparator(rightviewmenu);
     new FXMenuRadio(rightviewmenu,_("&Name"),rpanel->list,FileList::ID_SORT_BY_NAME);
     new FXMenuRadio(rightviewmenu,_("Si&ze"),rpanel->list,FileList::ID_SORT_BY_SIZE);
@@ -542,23 +563,21 @@ XFileExplorer::XFileExplorer(FXApp *app,char *title,FXIcon *bigicon,FXIcon *mini
     new FXMenuCommand(helpmenu,_("&About X File Explorer"),NULL,this,ID_ABOUT);
 
   	// Install some other key accelerators for compatibility with Midnight Commander
-	getAccelTable()->addAccel(FXSEL(0,KEY_F3),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_VIEW));
+	//getAccelTable()->addAccel(FXSEL(0,KEY_F3),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_VIEW));
 	getAccelTable()->addAccel(FXSEL(0,KEY_F4),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_EDIT));
 	getAccelTable()->addAccel(FXSEL(0,KEY_F6),lpanel->current,FXSEL(SEL_COMMAND,FilePanel::ID_FILE_MOVE));
 
     // Make a tool tip
     new FXToolTip(app,0);
-    
-	// Get autosave flag
-    auto_save_layout=getApp()->reg().readUnsignedEntry("OPTIONS","auto_save_layout",TRUE);
-    if (auto_save_layout==TRUE)
-		autosave->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_CHECK),NULL);
 }
-
+    
 // Save configuration when quitting
 void XFileExplorer::saveConfig()
 {
-    if(auto_save_layout==TRUE)
+	// Get autosave flag
+    FXbool auto_save_layout=getApp()->reg().readUnsignedEntry("OPTIONS","auto_save_layout",TRUE);
+
+	if(auto_save_layout==TRUE)
     {
 		getApp()->reg().writeUnsignedEntry("LEFT PANEL","name_size",lpanel->list->getHeaderSize(0));
         getApp()->reg().writeUnsignedEntry("LEFT PANEL","size_size",lpanel->list->getHeaderSize(1));
@@ -653,7 +672,8 @@ void XFileExplorer::saveConfig()
 		getApp()->reg().writeStringEntry("RIGHT PANEL","sort_func",sort_func.text());
         getApp()->reg().writeUnsignedEntry("RIGHT PANEL","ignore_case",rpanel->list->getIgnoreCase());
 
-        getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
+        // Global options
+		getApp()->reg().writeUnsignedEntry("OPTIONS","width",(FXuint)getWidth());
         getApp()->reg().writeUnsignedEntry("OPTIONS","height",(FXuint)getHeight());
         getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
         getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
@@ -661,15 +681,10 @@ void XFileExplorer::saveConfig()
 		getApp()->reg().writeUnsignedEntry("OPTIONS","locationbar",(FXuint)locationbar->shown());
         getApp()->reg().writeUnsignedEntry("OPTIONS","status",(FXuint)lpanel->statusbar->shown());
         getApp()->reg().writeUnsignedEntry("OPTIONS","panel_view",(FXuint)panel_view);
-        getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",(FXuint)warn_if_root);
-        getApp()->reg().writeUnsignedEntry("OPTIONS","use_trashcan",(FXuint)use_trashcan);
-#if defined(linux)
-        getApp()->reg().writeUnsignedEntry("OPTIONS","mount_warn",(FXuint)mount_warn);
-		getApp()->reg().writeUnsignedEntry("OPTIONS","mount_messages",(FXuint)mount_messages);
-#endif
         getApp()->reg().writeUnsignedEntry("OPTIONS","tree_width",(FXuint)dirpanel->getWidth());
         getApp()->reg().writeUnsignedEntry("OPTIONS","tree_hidden_dir",dirpanel->list->showHiddenFiles());
 
+
         FXString history="";
         for(int i=0;i<RunHistSize;i++)
         {
@@ -688,8 +703,7 @@ void XFileExplorer::saveConfig()
         if(OpenNum)
             getApp()->reg().writeStringEntry("HISTORY","open",history.text());
     }
-    getApp()->reg().writeUnsignedEntry("OPTIONS","auto_save_layout",auto_save_layout);
-    getApp()->reg().write();
+	getApp()->reg().write();
 }
 
 // Make application
@@ -710,6 +724,12 @@ void XFileExplorer::create()
     rpanel_tree_width=getApp()->reg().readUnsignedEntry("RIGHT PANEL","panel_tree_width",200);
 	switch(panel_view)
 	{
+	case ONE_PANEL:
+        rpanel->hide();
+        dirpanel->hide();
+		lpanel->setWidth(window_width-8);
+		rpanel->setWidth(rpanel_width);
+		break;
 	case TWO_PANELS:
         dirpanel->hide();
 		lpanel->setWidth(window_width-8-rpanel_width);
@@ -720,6 +740,10 @@ void XFileExplorer::create()
 		lpanel->setWidth(window_width-8-dirpanel_width);
 		rpanel->setWidth(rpanel_tree_width);
 		break;
+	case TREE_TWO_PANELS:
+		lpanel->setWidth(window_width-12-dirpanel_width-rpanel_tree_width);
+		rpanel->setWidth(rpanel_tree_width);
+		break;
 	}
 
     if(!getApp()->reg().readUnsignedEntry("OPTIONS","toolbar",TRUE))
@@ -736,17 +760,17 @@ void XFileExplorer::create()
     // Open left or right panel in starting directory (if specified) or in current directory
     if (startdir=="")
         startdir=FXFile::getCurrentDirectory();
-
-    liststyle=getApp()->reg().readUnsignedEntry("LEFT PANEL","liststyle",(FXuint)FXIconList::ID_SHOW_DETAILS);
     lpanel->list->setDirectory(startdir);
     lpanel->label->setText(startdir);
-    lpanel->list->setListStyle(liststyle);
-    dirpanel->list->setDirectory(startdir,TRUE);
-
-    liststyle=getApp()->reg().readUnsignedEntry("RIGHT PANEL","liststyle",(FXuint)FXIconList::ID_SHOW_DETAILS);
     rpanel->list->setDirectory(startdir);
     rpanel->label->setText(startdir);
-    rpanel->list->setListStyle(liststyle);
+	dirpanel->list->setDirectory(startdir,TRUE);
+    
+	// Set file panels list style
+	liststyle=getApp()->reg().readUnsignedEntry("LEFT PANEL","liststyle",(FXuint)FXIconList::ID_SHOW_DETAILS);
+	lpanel->list->setListStyle(liststyle|ICONLIST_AUTOSIZE);
+    liststyle=getApp()->reg().readUnsignedEntry("RIGHT PANEL","liststyle",(FXuint)FXIconList::ID_SHOW_DETAILS);
+    rpanel->list->setListStyle(liststyle|ICONLIST_AUTOSIZE);
 
 	// Show or hide hidden files listed in panels
     FXbool hiddenfiles;
@@ -767,23 +791,8 @@ void XFileExplorer::create()
     showthumbnails=getApp()->reg().readUnsignedEntry("RIGHT PANEL","showthumbnails",0);
     rpanel->list->showThumbnails(showthumbnails);
 	
-	// Get external programs settings
-	editor=getApp()->reg().readStringEntry("PROGS","editor","nedit ");
-    viewer=getApp()->reg().readStringEntry("PROGS","viewer","xfv ");
-    xterm=getApp()->reg().readStringEntry("PROGS","xterm","xterm -sb");
-
-    warn_if_root=getApp()->reg().readUnsignedEntry("OPTIONS","root_warn",TRUE);
-    use_trashcan=getApp()->reg().readUnsignedEntry("OPTIONS","use_trashcan",TRUE);
-    confirm_quit=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_quit",TRUE);
-    confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
-    confirm_overwrite=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_overwrite",TRUE);
-    ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
+    // History
     FXString history=getApp()->reg().readStringEntry("HISTORY","run","");
-#if defined(linux)
-	mount_warn=getApp()->reg().readUnsignedEntry("OPTIONS","mount_warn",TRUE);
-	mount_messages=getApp()->reg().readUnsignedEntry("OPTIONS","mount_messages",TRUE);
-#endif
-
    	int i;
     FXString histent;
     if(history != "")
@@ -799,7 +808,6 @@ void XFileExplorer::create()
     }
     else
         RunHistSize=0;
-
     history=getApp()->reg().readStringEntry("HISTORY","open","");
     histent="";
     if(history != "")
@@ -819,7 +827,8 @@ void XFileExplorer::create()
     getApp()->forceRefresh();
 
 	// Running as root?
-    if(getuid()==0 && warn_if_root)
+    FXbool root_warn=getApp()->reg().readUnsignedEntry("OPTIONS","root_warn",TRUE);
+	if(getuid()==0 && root_warn)
         MessageBox::information(this,MBOX_OK,_("Warning"),_("Running Xfe as root!"));
 
 	// Show window
@@ -827,6 +836,7 @@ void XFileExplorer::create()
 
 #if defined(linux)
 	// Warning message if a mount point is down
+	FXbool mount_warn=getApp()->reg().readUnsignedEntry("OPTIONS","mount_warn",TRUE);
 	if (mount_warn)
 	{
 		FXint d;
@@ -839,19 +849,58 @@ void XFileExplorer::create()
 #endif
 
     // Create trash can directory if it doesn't exist
+	int mask;
 	FXString homelocation=getenv("HOME");
     if(homelocation=="")
         homelocation=ROOTDIR;
 	trashlocation=homelocation+PATHSEPSTRING+TRASHNAME;
-	if (!exists(trashlocation))
+	if (!::exists(trashlocation))
 	{
-		// Create the trash can directory
-		FXint ret=::mkdir(trashlocation.text(),0755);
+		// Create the trash can directory according to the umask
+		mask=umask(0);
+		umask(mask);
+		FXint ret=::mkdir(trashlocation.text(),511 & ~mask);
 		if (ret==-1)
          	MessageBox::error(this,MBOX_OK,_("Error"),"Cannot create trash can directory '%s': %s",trashlocation.text(),strerror(errno));
     		// And what to do after that?
 	}
 
+	// If no Xfe local configuration exists (i.e. at first call or after a purge of the configuration file),
+	// copy the global Desktop file to the local Xfe configuration file, and read / write the registry
+	FXString configpath=homelocation+"/.foxrc/XFileExplorer/Xfe";
+	if (!::exists(configpath))
+	{
+		// Create ~/.foxrc directory if it doesn't exist	
+		FXString configlocation=homelocation+"/.foxrc";
+		if (!::exists(configlocation))
+		{
+			// Create the .foxrc directory according to the umask
+			mask=umask(0);
+			umask(mask);
+			FXint ret=::mkdir(configlocation.text(),511 & ~mask);
+			if (ret==-1)
+				MessageBox::error(this,MBOX_OK,_("Error"),"Cannot create .foxrc directory '%s': %s",configlocation.text(),strerror(errno));
+			
+			// Create the XFileExplorer directory according to the umask
+			configlocation=homelocation+"/.foxrc/XFileExplorer";
+			ret=::mkdir(configlocation.text(),511 & ~mask);
+			if (ret==-1)
+				MessageBox::error(this,MBOX_OK,_("Error"),"Cannot create .XFileExplorer directory '%s': %s",configlocation.text(),strerror(errno));
+		}
+		
+		// Copy the global Desktop file (three possible locations) to the local configuration file
+		if (::exists("/etc/foxrc/Desktop"))
+			FXFile::copy("/etc/foxrc/Desktop",configpath,FALSE);
+		else if (::exists("/usr/lib/foxrc/Desktop"))
+			FXFile::copy("/usr/lib/foxrc/Desktop",configpath,FALSE);		
+		else if (::exists("/usr/local/lib/foxrc/Desktop"))
+			FXFile::copy("/usr/local/lib/foxrc/Desktop",configpath,FALSE);
+
+		// Read and write the registry
+		getApp()->reg().read();
+		getApp()->reg().write();
+	}
+
 	// Eventually start iconic or maximized
 	if (iconic)
 		minimize();
@@ -895,6 +944,15 @@ long XFileExplorer::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 				lpanel->list->setCurrentItem(current);
 				lpanel->list->selectItem(current);
 			}
+			else if ( (rpanel->shown()) && (lpanel->list->hasFocus()) )
+			{
+				rpanel->list->setFocus();
+				current=rpanel->list->getCurrentItem();
+				if (current<0)
+					current=0;
+				rpanel->list->setCurrentItem(current);
+				rpanel->list->selectItem(current);			
+			}			
 			else
 			{
 				dirpanel->list->setFocus();
@@ -904,7 +962,7 @@ long XFileExplorer::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 				lpanel->list->deselectItem(current);
 			}
 		}
-		else
+		else if (rpanel->shown())
 		{
 			if (lpanel->current==rpanel)
 			{
@@ -948,7 +1006,8 @@ long XFileExplorer::onKeyPress(FXObject* sender,FXSelector sel,void* ptr)
 // Handle quitting
 long XFileExplorer::onQuit(FXObject*,FXSelector,void*)
 {
-    if(confirm_quit)
+    FXbool confirm_quit=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_quit",TRUE);
+	if(confirm_quit)
         if(MBOX_CLICKED_CANCEL==MessageBox::question(this,MBOX_QUIT_CANCEL,_("Quitting Xfe"),_("Do you really want to quit Xfe?")))
             return 1;
     saveConfig();
@@ -1033,11 +1092,18 @@ long  XFileExplorer::onCmdRestart(FXObject*,FXSelector,void*)
     return 1;
 }
 
+// Start a new Xfe session
+long  XFileExplorer::onCmdNewWindow(FXObject*,FXSelector,void*)
+{
+	system("xfe &");
+    return 1;
+}
 
 // Run Terminal
 long  XFileExplorer::onCmdXTerm(FXObject*,FXSelector,void*)
 {
-    chdir(lpanel->current->list->getDirectory().text());
+    FXString xterm=getApp()->reg().readStringEntry("PROGS","xterm","xterm -sb");
+	chdir(lpanel->current->list->getDirectory().text());
     FXString cmd=xterm;
     cmd += " &";
     system(cmd.text());
@@ -1073,7 +1139,7 @@ long XFileExplorer::onCmdAbout(FXObject*,FXSelector,void*)
 {
     FXPNGIcon icon(getApp(),FileManager);
     char msg[1000];
-    snprintf(msg,sizeof(msg)-1,_("XFE, X File Explorer Version %s\n\nCopyright (C) 2002-2005 Roland Baudin (roland65@free.fr)\n\nBased on X WinCommander by Maxim Baranov\n"),VERSION);
+    snprintf(msg,sizeof(msg)-1,_("XFE, X File Explorer Version %s\n\nCopyright (C) 2002-2006 Roland Baudin (roland65@free.fr)\n\nBased on X WinCommander by Maxim Baranov\n"),VERSION);
     MessageBox about(this,_("About X File Explorer"),msg,&icon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
     about.execute(PLACEMENT_CURSOR);
     lpanel->current->list->setFocus();
@@ -1137,6 +1203,15 @@ long XFileExplorer::onCmdShowPanels(FXObject* sender,FXSelector sel,void* ptr)
 
     switch(FXSELID(sel))
     {
+    case ID_SHOW_ONE_PANEL:
+		panel_view=ONE_PANEL;
+		lpanel->setWidth(window_width-8);
+		rpanel->setWidth(rpanel_width);
+		if (dirpanel->shown())
+    		dirpanel->handle(sender,FXSEL(SEL_COMMAND,DirPanel::ID_TOGGLE_TREE),ptr);
+		if (rpanel->shown())
+			rpanel->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
+        break;
     case ID_SHOW_TWO_PANELS:
 		panel_view=TWO_PANELS;
 		lpanel->setWidth(window_width-8-rpanel_width);
@@ -1155,6 +1230,15 @@ long XFileExplorer::onCmdShowPanels(FXObject* sender,FXSelector sel,void* ptr)
 		if (rpanel->shown())
 			rpanel->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
         break;
+    case ID_SHOW_TREE_TWO_PANELS:
+		panel_view=TREE_TWO_PANELS;
+		lpanel->setWidth(window_width-12-dirpanel_width-rpanel_tree_width);
+		rpanel->setWidth(rpanel_tree_width);
+		if (!dirpanel->shown())
+    		dirpanel->handle(sender,FXSEL(SEL_COMMAND,DirPanel::ID_TOGGLE_TREE),ptr);
+		if (!rpanel->shown())
+			rpanel->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
+        break;
     }
 	return 1;
 }
@@ -1166,6 +1250,21 @@ long XFileExplorer::onUpdShowPanels(FXObject* sender,FXSelector sel,void* ptr)
 		
     switch(FXSELID(sel))
     {
+    case ID_SHOW_ONE_PANEL:
+		if (!dirpanel->shown() && !rpanel->shown())
+		{
+            msg = FXWindow::ID_CHECK;		
+			rpanel_width=rpanel->getWidth();
+        	if(rmenutitle->shown())
+        	{
+            	lpanel->focus();
+            	rmenutitle->hide();
+            	lmenutitle->setText(_("&Panel"));
+            	lpanel->focus();
+        	}
+		}
+        break;
+    
 	case ID_SHOW_TWO_PANELS:
 		if (!dirpanel->shown() && rpanel->shown())
 		{
@@ -1195,35 +1294,31 @@ long XFileExplorer::onUpdShowPanels(FXObject* sender,FXSelector sel,void* ptr)
        	 	}
 		}
         break;
+    
+	case ID_SHOW_TREE_TWO_PANELS:
+ 		if (dirpanel->shown() && rpanel->shown())
+		{
+            msg = FXWindow::ID_CHECK;
+			rpanel_tree_width=rpanel->getWidth();
+        	if(!rmenutitle->shown())
+        	{
+           	 	rmenutitle->show();
+            	rmenutitle->setText(_("&Right panel"));
+            	lmenutitle->setText(_("&Left panel"));
+            	lpanel->focus();
+        	}
+		}
+        break;
     }
     sender->handle(this,FXSEL(SEL_COMMAND,msg),ptr);
     return 1;
 }
 
 
-
-// Toggle autosave flag
-long XFileExplorer::onCmdAutoSave(FXObject* sender,FXSelector,void*)
-{
-    if(auto_save_layout==TRUE)
-    {
-        auto_save_layout=FALSE;
-        sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_UNCHECK),NULL);
-    }
-    else
-    {
-        auto_save_layout=TRUE;
-        sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_CHECK),NULL);
-    }
-    return 1;
-}
-
-
-
 // Preferences
 long XFileExplorer::onCmdPrefs(FXObject*,FXSelector s,void *p)
 {
-    PreferencesBox *prefs=new PreferencesBox(this);
+    PreferencesBox *prefs=new PreferencesBox(this,listbackcolor,listforecolor);
     prefs->execute(PLACEMENT_SCREEN);
     delete prefs;
     lpanel->current->list->setFocus();
@@ -1231,21 +1326,6 @@ long XFileExplorer::onCmdPrefs(FXObject*,FXSelector s,void *p)
 }
 
 
-// Reload preferences
-long XFileExplorer::onCmdReloadPrefs(FXObject*,FXSelector s,void *p)
-{
-    editor=getApp()->reg().readStringEntry("PROGS","editor","nedit");
-    viewer=getApp()->reg().readStringEntry("PROGS","viewer","xfv");
-    xterm=getApp()->reg().readStringEntry("PROGS","xterm","xterm -sb");
-
-    confirm_quit=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_quit",TRUE);
-    confirm_del=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_delete",TRUE);
-    confirm_overwrite=getApp()->reg().readUnsignedEntry("OPTIONS","confirm_overwrite",TRUE);
-    ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
-    return 1;
-}
-
-
 long XFileExplorer::onCmdToggleStatus(FXObject*,FXSelector s,void *p)
 {
     dirpanel->statusbar->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),NULL);
@@ -1343,7 +1423,7 @@ long XFileExplorer::onCmdEmptyTrashcan(FXObject*,FXSelector sel,void* ptr)
 	delete f;
 	
 	// Re-create the trash can directory
-	if (!exists(trashlocation))
+	if (!::exists(trashlocation))
 	{
 		FXint ret=::mkdir(trashlocation.text(),0755);
 		if (ret==-1)
@@ -1363,6 +1443,7 @@ long XFileExplorer::onCmdEmptyTrashcan(FXObject*,FXSelector sel,void* ptr)
 // Update the empty trash can menu item
 long XFileExplorer::onUpdEmptyTrashcan(FXObject* o,FXSelector,void*)
 {
+	FXbool use_trashcan=getApp()->reg().readUnsignedEntry("OPTIONS","use_trashcan",TRUE);
 	if (use_trashcan)
 		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
 	else
@@ -1380,6 +1461,8 @@ long XFileExplorer::onCmdFileMan(FXObject*,FXSelector sel,void* ptr)
 
     lpanel->current->list->setFocus();
 
+	FXbool ask_before_copy=getApp()->reg().readUnsignedEntry("OPTIONS","ask_before_copy",TRUE);
+	
 	// Extract target directory, number of sources and sources names
 	FXString str=(char*)ptr;
 
