@@ -33,8 +33,10 @@ protected:
 	int rpanel_tree_width;
 	enum
 	{
+		ONE_PANEL,
 		TWO_PANELS,
 		TREE_PANEL,
+		TREE_TWO_PANELS
 	};	
 	int panel_view;
     int RunHistSize;
@@ -53,7 +55,6 @@ protected:
     DirPanel		*dirpanel;
     FilePanel		*lpanel;
     FilePanel		*rpanel;
-    FXbool			auto_save_layout;
     FXString		target;
     FXString		sources;
     char			*opendir;
@@ -64,6 +65,8 @@ protected:
 	FXint			ypos;
 	FXuint			width;
 	FXuint			height;
+	FXColor			listbackcolor;
+	FXColor			listforecolor;
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -83,13 +86,14 @@ public:
 		ID_GOTO_LOCATION,
         ID_RUN,
         ID_PREFS,
-        ID_RELOAD_PREFS,
-        ID_AUTO_SAVE,
         ID_DIR_BOX,
         ID_TOGGLE_STATUS,
+		ID_SHOW_ONE_PANEL,
 		ID_SHOW_TWO_PANELS,
 		ID_SHOW_TREE_PANEL,
+		ID_SHOW_TREE_TWO_PANELS,
         ID_RESTART,
+        ID_NEW_WIN,
         ID_BOOKMARK,
         ID_ADD_BOOKMARK,
         ID_QUIT,
@@ -110,17 +114,16 @@ public:
     long onCmdAbout(FXObject*,FXSelector,void*);
     long onCmdFileAssoc(FXObject*,FXSelector,void*);
 	long onCmdRefresh(FXObject*,FXSelector,void*);
-    long onCmdAutoSave(FXObject*,FXSelector,void*);
     long onCmdToggleStatus(FXObject*,FXSelector,void*);
     long onCmdPopupMenu(FXObject*,FXSelector,void*);
     long onCmdPrefs(FXObject*,FXSelector,void*);
-    long onCmdReloadPrefs(FXObject*,FXSelector,void*);
     long onCmdRun(FXObject*,FXSelector,void*);
     long onCmdXTerm(FXObject*,FXSelector,void*);
 	long onCmdEmptyTrashcan(FXObject*,FXSelector,void*);
     long onCmdFileMan(FXObject*,FXSelector,void*);
 	long onCmdShowPanels(FXObject*,FXSelector,void*);
     long onCmdRestart(FXObject*,FXSelector,void*);
+	long onCmdNewWindow(FXObject*,FXSelector,void*);
     long onCmdBookmark(FXObject*,FXSelector,void*);
 	long onCmdGotoLocation(FXObject*,FXSelector,void*);
 	long onCmdClearLocation(FXObject*,FXSelector,void*);
