@@ -27,6 +27,7 @@
 
 FXMainWindow *mainWindow;
 char **args;
+FXColor listbackcolor, listforecolor;
 
 // Predefined zoom factors 
 #define NB_ZOOM 24
@@ -91,8 +92,8 @@ FXDEFMAP(XFileImage) XFileImageMap[]={
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_OUT,XFileImage::onCmdZoomOut),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_100,XFileImage::onCmdZoom100),
                                         FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ZOOM_WIN,XFileImage::onCmdZoomWin),
-	                                    FXMAPFUNC(SEL_COMMAND,XFileImage::ID_PRINT,XFileImage::onCmdPrint),
-                                        FXMAPFUNC(SEL_UPDATE,XFileImage::ID_PRINT,XFileImage::onUpdImage),
+	                                    //FXMAPFUNC(SEL_COMMAND,XFileImage::ID_PRINT,XFileImage::onCmdPrint),
+                                        //FXMAPFUNC(SEL_UPDATE,XFileImage::ID_PRINT,XFileImage::onUpdImage),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_90,XFileImage::onUpdImage),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROTATE_270,XFileImage::onUpdImage),
                                         FXMAPFUNC(SEL_UPDATE,XFileImage::ID_MIRROR_HOR,XFileImage::onUpdImage),
@@ -140,7 +141,7 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     FXPNGIcon *zoomwinicon=new FXPNGIcon(getApp(),zoomwin);
    	FXPNGIcon *mirrorhoricon=new FXPNGIcon(getApp(),fliplr);
     FXPNGIcon *mirrorvericon=new FXPNGIcon(getApp(),flipud);
-	FXPNGIcon *printicon=new FXPNGIcon(getApp(),print);	
+	//FXPNGIcon *printicon=new FXPNGIcon(getApp(),print);	
 	FXPNGIcon *showhiddenicon=new FXPNGIcon(getApp(),showhidden);
 	FXPNGIcon *hidehiddenicon=new FXPNGIcon(getApp(),hidehidden);
 	FXPNGIcon *showthumbicon=new FXPNGIcon(getApp(),showthumb);
@@ -200,6 +201,8 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     label->setTarget(this);
     label->setSelector(FXSEL(0,XFileImage::ID_LABEL));
     filelist=new FileList(fileframe,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE);
+	filelist->setTextColor(listforecolor);
+	filelist->setBackColor(listbackcolor);
 
     // Status bar
 	statusbar=new FXHorizontalFrame(fileframe,JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 3,3,0,0);
@@ -215,7 +218,7 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
     new FXButton(toolbar,_("\tOpen Image (Ctrl-O)\tOpen image file. (Ctrl-O)"),fileopenicon,this,ID_OPEN,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Toolbar button: Print
-	new FXButton(toolbar,_("\tPrint image (Ctrl-P)\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT,BUTTON_TOOLBAR|FRAME_RAISED);
+	//new FXButton(toolbar,_("\tPrint image (Ctrl-P)\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT,BUTTON_TOOLBAR|FRAME_RAISED);
 
     // Toolbar button: Quit
     new FXButton(toolbar,_("\tQuit Xfi (Ctrl-Q)\tQuit Xfi. (Ctrl-Q)"),quiticon,this,ID_QUIT,BUTTON_TOOLBAR|FRAME_RAISED);
@@ -262,7 +265,7 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL,0,0,6
 
     // File Menu entries
     new FXMenuCommand(filemenu,_("&Open...\tCtrl-O\tOpen image file. (Ctrl-O)"),fileopenicon,this,ID_OPEN);
-    new FXMenuCommand(filemenu,_("&Print image...\tCtrl-P\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT);
+    //new FXMenuCommand(filemenu,_("&Print image...\tCtrl-P\tPrint image file. (Ctrl-P)"),printicon,this,ID_PRINT);
 
     // Recent file menu; this automatically hides if there are no files
     FXMenuSeparator* sep1=new FXMenuSeparator(filemenu);
@@ -352,7 +355,7 @@ XFileImage::~XFileImage()
 long XFileImage::onCmdAbout(FXObject*,FXSelector,void*)
 {
     FXPNGIcon icon(getApp(),xfi);
-    MessageBox about(this,_("About X File Image"),_("X File Image is a simple image viewer.\n\nCopyright (C) 2002-2005 Roland Baudin (roland65@free.fr)"),&icon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
+    MessageBox about(this,_("About X File Image"),_("X File Image is a simple image viewer.\n\nCopyright (C) 2002-2006 Roland Baudin (roland65@free.fr)"),&icon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
     about.execute();
     return 1;
 }
@@ -496,6 +499,7 @@ long XFileImage::onCmdOpen(FXObject*,FXSelector,void*)
 }
 
 
+/*
 // Print the image
 long XFileImage::onCmdPrint(FXObject*,FXSelector,void*)
 {
@@ -505,6 +509,7 @@ long XFileImage::onCmdPrint(FXObject*,FXSelector,void*)
     	dlg.getPrinter(printer);
   	return 1;
 }
+*/
 
 // Handle toggle hidden command
 long XFileImage::onCmdToggleHidden(FXObject* sender,FXSelector sel,void* ptr)
@@ -1122,6 +1127,8 @@ int main(int argc,char *argv[])
     selforecolor=reg->readColorEntry("SETTINGS","selforecolor",FXRGB(255,255,255));
     selbackcolor=reg->readColorEntry("SETTINGS","selbackcolor",FXRGB(10,36,106));
     bordercolor=reg->readColorEntry("SETTINGS","bordercolor",FXRGB(0,0,0));
+	listbackcolor=reg->readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
+	listforecolor=reg->readColorEntry("SETTINGS","listforecolor",FXRGB(0,0,0));
 	application->setBaseColor(basecolor);
 	application->setForeColor(forecolor);
 	application->setBackColor(backcolor);
