@@ -39,7 +39,7 @@ protected:
 public:
     long onCmdAbout(FXObject*,FXSelector,void*);
     long onCmdOpen(FXObject*,FXSelector,void*);
-	long onCmdPrint(FXObject*,FXSelector,void*);
+	//long onCmdPrint(FXObject*,FXSelector,void*);
 	long onCmdShowMini(FXObject*,FXSelector,void*);
  	long onCmdShowBig(FXObject*,FXSelector,void*);
  	long onCmdShowDetails(FXObject*,FXSelector,void*);
@@ -77,7 +77,7 @@ public:
 		ID_COLS,
 		ID_ROWS,
         ID_TITLE,
-		ID_PRINT,
+		//ID_PRINT,
         ID_QUIT,
         ID_FILELIST,
         ID_RECENTFILE,
