@@ -26,9 +26,10 @@ public:
     long onCmdQuit(FXObject*,FXSelector,void*);
     long onCmdFind(FXObject*,FXSelector,void*);
     long onCmdColors(FXObject*,FXSelector,void*);
-	long onCmdPrint(FXObject*,FXSelector,void*);
+	//long onCmdPrint(FXObject*,FXSelector,void*);
 	long onUpdMenu(FXObject* sender,FXSelector,void*);
     long onUpdTitle(FXObject*,FXSelector,void*);
+
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
@@ -39,7 +40,7 @@ public:
         ID_FIND_AGAIN,
         ID_COLORS,
         ID_QUIT,
-		ID_PRINT,
+		//ID_PRINT,
         ID_LAST
     };
 public:
